@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -93,7 +93,7 @@ public final class Utils {
      * @return true if given set contains at least one superclass of provided instance, false otherwise.
      */
     public static <X, Y> boolean containsSuperclass(Set<? extends Class<? extends Y>> classes, X subclassInstance) {
-        Class subclass = subclassInstance.getClass();
+        Class<?> subclass = subclassInstance.getClass();
         for (Class<? extends Y> classs : classes) if (classs.isAssignableFrom(subclass)) return true;
         return false;
     }
@@ -109,7 +109,7 @@ public final class Utils {
      * @return filtered set containing only instances of the given class.
      */
     public static <X, Y extends X, Z extends X> Set<Z> getFilteredSet(Set<Y> set, Class<Z> filter) {
-        Set<Z> filteredSet = new HashSet();
+        Set<Z> filteredSet = new HashSet<>();
         for (Y item : set) if (filter.isInstance(item)) filteredSet.add((Z)item);
         return filteredSet;
     }
@@ -123,7 +123,7 @@ public final class Utils {
      */
     public static <X extends DataSource> List<X> getSortedDataSources(Set<X> dataSources) {
         List<DataSourcePath<X>> dataSourcePaths = getSortedDataSourcePaths(dataSources);
-        List<X> sortedDataSources = new ArrayList();
+        List<X> sortedDataSources = new ArrayList<>();
         
         for (DataSourcePath<X> dataSourcePath : dataSourcePaths)
             sortedDataSources.add(dataSourcePath.getDataSource());
@@ -152,7 +152,7 @@ public final class Utils {
      * @return Set of independent DataSources.
      */
     public static <X extends DataSource> Set<X> getIndependentDataSources(Set<X> dataSources) {
-        Map<Integer, Set<X>> independentDataSourcesMap = new HashMap();
+        Map<Integer, Set<X>> independentDataSourcesMap = new HashMap<>();
         List<DataSourcePath<X>> dataSourcePaths = getSortedDataSourcePaths(dataSources);
         
         for (DataSourcePath<X> dataSourcePath : dataSourcePaths) {
@@ -169,14 +169,14 @@ public final class Utils {
             if (independent) {
                 Set<X> set = independentDataSourcesMap.get(dataSourcePath.size() - 1);
                 if (set == null) {
-                    set = new HashSet();
+                    set = new HashSet<>();
                     independentDataSourcesMap.put(dataSourcePath.size() - 1, set);
                 }
                 set.add(dataSourcePath.getDataSource());
             }
         }
         
-        Set<X> independentDataSources = new HashSet();
+        Set<X> independentDataSources = new HashSet<>();
         Collection<Set<X>> independentSetsCollection = independentDataSourcesMap.values();
         for (Set<X> independentSet : independentSetsCollection)
             independentDataSources.addAll(independentSet);
@@ -184,7 +184,7 @@ public final class Utils {
     }
     
     private static <X extends DataSource> List<DataSourcePath<X>> getSortedDataSourcePaths(Set<X> dataSources) {
-        List<DataSourcePath<X>> dataSourcePaths = new ArrayList();
+        List<DataSourcePath<X>> dataSourcePaths = new ArrayList<>();
         for (DataSource dataSource : dataSources) dataSourcePaths.add(new DataSourcePath(dataSource));
         Collections.sort(dataSourcePaths);
         return dataSourcePaths;
@@ -192,7 +192,7 @@ public final class Utils {
     
     private static class DataSourcePath<X extends DataSource> extends ArrayList<DataSource> implements Comparable<DataSourcePath> {
         
-        public DataSourcePath(X dataSource) {
+        DataSourcePath(X dataSource) {
             super();
             DataSource ds = dataSource;
             while(ds != null) {
@@ -220,7 +220,7 @@ public final class Utils {
      * @return filename without extension.
      */
     public static String getFileBase(String fileName) {
-        int extIndex = fileName.lastIndexOf("."); // NOI18N
+        int extIndex = fileName.lastIndexOf('.'); // NOI18N
         if (extIndex == -1) return fileName;
         return fileName.substring(0, extIndex);
     }
@@ -232,7 +232,7 @@ public final class Utils {
      * @return file extension.
      */
     public static String getFileExt(String fileName) {
-        int extIndex = fileName.lastIndexOf("."); // NOI18N
+        int extIndex = fileName.lastIndexOf('.'); // NOI18N
         if (extIndex == -1) return ""; // NOI18N
         return fileName.substring(extIndex);
     }
@@ -326,7 +326,9 @@ public final class Utils {
         
         if (file.isDirectory()) {
             File[] files = file.listFiles();
-            for (int i = 0; i < files.length; i++) delete(files[i], deleteOnExit);
+            for (File file1 : files) {
+                delete(file1, deleteOnExit);
+            }
         }
 
         if (!file.delete()) {
