@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,6 +25,18 @@
 
 package org.graalvm.visualvm.heapviewer.java.impl;
 
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.Iterator;
+import java.util.List;
+import java.util.Map;
+import javax.accessibility.AccessibleContext;
+import javax.swing.Icon;
+import javax.swing.JComponent;
+import javax.swing.JLabel;
+import javax.swing.SortOrder;
+import javax.swing.UIManager;
 import org.graalvm.visualvm.heapviewer.HeapContext;
 import org.graalvm.visualvm.heapviewer.java.ClassNode;
 import org.graalvm.visualvm.heapviewer.java.ClassNodeRenderer;
@@ -39,21 +51,10 @@ import org.graalvm.visualvm.heapviewer.ui.HeapViewerRenderer;
 import org.graalvm.visualvm.heapviewer.ui.UIThresholds;
 import org.graalvm.visualvm.heapviewer.utils.NodesComputer;
 import org.graalvm.visualvm.heapviewer.utils.ProgressIterator;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.HashMap;
-import java.util.Iterator;
-import java.util.List;
-import java.util.Map;
-import javax.accessibility.AccessibleContext;
-import javax.swing.Icon;
-import javax.swing.JComponent;
-import javax.swing.JLabel;
-import javax.swing.SortOrder;
-import javax.swing.UIManager;
 import org.graalvm.visualvm.lib.jfluid.heap.Heap;
 import org.graalvm.visualvm.lib.jfluid.heap.Instance;
 import org.graalvm.visualvm.lib.jfluid.heap.JavaClass;
+import org.graalvm.visualvm.lib.jfluid.heap.ObjectArrayInstance;
 import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
 import org.graalvm.visualvm.lib.profiler.api.icons.LanguageIcons;
 import org.openide.util.lookup.ServiceProvider;
@@ -323,7 +324,7 @@ class JavaDiffClassesProvider {
         private ClassNodeRenderer externalRenderer;
         
         
-        public DiffClassNodeRenderer(Heap heap) {
+        DiffClassNodeRenderer(Heap heap) {
             this.heap = heap;
         }
         
@@ -450,6 +451,16 @@ class JavaDiffClassesProvider {
             return null;
         }
 
+        @Override
+        public ObjectArrayInstance getSigners() {
+            return null;
+        }
+
+        @Override
+        public Instance getProtectionDomain() {
+            return null;
+        }
+
         @Override
         public List getFields() {
             return null;
@@ -505,6 +516,11 @@ class JavaDiffClassesProvider {
             return null;
         }
         
+        @Override
+        public Heap getHeap() {
+            return null;
+        }
+
         @Override
         public boolean equals(Object o) {
             if (o == this) return true;
