@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -40,12 +40,6 @@ import javax.swing.JMenu;
 import javax.swing.JPopupMenu;
 import javax.swing.SortOrder;
 import javax.swing.SwingUtilities;
-import org.graalvm.visualvm.lib.jfluid.heap.FieldValue;
-import org.graalvm.visualvm.lib.jfluid.heap.Heap;
-import org.graalvm.visualvm.lib.jfluid.heap.Instance;
-import org.graalvm.visualvm.lib.jfluid.heap.JavaClass;
-import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
-import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
 import org.graalvm.visualvm.heapviewer.HeapContext;
 import org.graalvm.visualvm.heapviewer.java.InstanceNode;
 import org.graalvm.visualvm.heapviewer.java.InstancesWrapper;
@@ -71,9 +65,15 @@ import org.graalvm.visualvm.heapviewer.utils.ProgressIterator;
 import org.graalvm.visualvm.heapviewer.utils.counters.InstanceCounter;
 import org.graalvm.visualvm.heapviewer.utils.counters.PrimitiveCounter;
 import org.graalvm.visualvm.lib.jfluid.heap.Field;
+import org.graalvm.visualvm.lib.jfluid.heap.FieldValue;
+import org.graalvm.visualvm.lib.jfluid.heap.Heap;
+import org.graalvm.visualvm.lib.jfluid.heap.Instance;
+import org.graalvm.visualvm.lib.jfluid.heap.JavaClass;
 import org.graalvm.visualvm.lib.jfluid.heap.ObjectFieldValue;
 import org.graalvm.visualvm.lib.jfluid.heap.Type;
+import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
 import org.graalvm.visualvm.lib.profiler.api.icons.LanguageIcons;
+import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
 import org.graalvm.visualvm.lib.ui.swing.renderer.NormalBoldGrayRenderer;
 import org.openide.util.NbBundle;
 import org.openide.util.NbPreferences;
@@ -128,18 +128,18 @@ class JavaFieldsPlugin extends HeapViewPlugin {
     private final TreeTableView objectsView;
     
 
-    public JavaFieldsPlugin(HeapContext context, HeapViewerActions actions) {
+    JavaFieldsPlugin(HeapContext context, HeapViewerActions actions) {
         super(Bundle.JavaFieldsPlugin_Name(), Bundle.JavaFieldsPlugin_Description(), Icons.getIcon(ProfilerIcons.NODE_FORWARD));
         
         heap = context.getFragment().getHeap();
         
         TreeTableViewColumn[] columns = new TreeTableViewColumn[] {
-            new TreeTableViewColumn.Name(heap),
-            new TreeTableViewColumn.LogicalValue(heap),
+            new TreeTableViewColumn.Name(),
+            new TreeTableViewColumn.LogicalValue(),
             new TreeTableViewColumn.Count(heap, true, true),
             new TreeTableViewColumn.OwnSize(heap, false, false),
             new TreeTableViewColumn.RetainedSize(heap, false, false),
-            new TreeTableViewColumn.ObjectID(heap)
+            new TreeTableViewColumn.ObjectID()
         };
         objectsView = new TreeTableView("java_objects_fields", context, actions, columns) { // NOI18N
             @Override
@@ -669,7 +669,7 @@ class JavaFieldsPlugin extends HeapViewPlugin {
     
     // TODO: make JavaClass.getAllInstanceFields() public?
     private static List<Field> getAllInstanceFields(JavaClass jclass) {
-        List fields = new ArrayList(50);
+        List<Field> fields = new ArrayList(50);
 
         for (JavaClass jcls = jclass; jcls != null; jcls = jcls.getSuperClass()) {
             fields.addAll(jcls.getFields());
