@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -32,20 +32,14 @@ import javax.swing.AbstractAction;
 import javax.swing.Action;
 import javax.swing.ButtonGroup;
 import javax.swing.Icon;
+import javax.swing.JButton;
 import javax.swing.JComponent;
 import javax.swing.JMenuItem;
 import javax.swing.JPopupMenu;
 import javax.swing.JToggleButton;
 import javax.swing.SortOrder;
 import javax.swing.SwingUtilities;
-import org.graalvm.visualvm.lib.jfluid.heap.Heap;
-import org.graalvm.visualvm.lib.jfluid.heap.JavaClass;
-import org.graalvm.visualvm.lib.ui.components.ProfilerToolbar;
-import org.graalvm.visualvm.lib.ui.swing.ActionPopupButton;
-import org.graalvm.visualvm.lib.ui.swing.GrayLabel;
-import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
-import org.graalvm.visualvm.lib.profiler.api.icons.LanguageIcons;
-import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
+import org.graalvm.visualvm.core.VisualVM;
 import org.graalvm.visualvm.heapviewer.HeapContext;
 import org.graalvm.visualvm.heapviewer.java.JavaHeapFragment;
 import org.graalvm.visualvm.heapviewer.model.DataType;
@@ -57,10 +51,16 @@ import org.graalvm.visualvm.heapviewer.ui.HeapView;
 import org.graalvm.visualvm.heapviewer.ui.HeapViewerActions;
 import org.graalvm.visualvm.heapviewer.ui.HeapViewerFeature;
 import org.graalvm.visualvm.heapviewer.ui.PluggableTreeTableView;
-import org.graalvm.visualvm.heapviewer.ui.TreeTableViewColumn;
-import javax.swing.JButton;
-import org.graalvm.visualvm.core.VisualVM;
 import org.graalvm.visualvm.heapviewer.ui.TreeTableView;
+import org.graalvm.visualvm.heapviewer.ui.TreeTableViewColumn;
+import org.graalvm.visualvm.lib.jfluid.heap.Heap;
+import org.graalvm.visualvm.lib.jfluid.heap.JavaClass;
+import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
+import org.graalvm.visualvm.lib.profiler.api.icons.LanguageIcons;
+import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
+import org.graalvm.visualvm.lib.ui.components.ProfilerToolbar;
+import org.graalvm.visualvm.lib.ui.swing.ActionPopupButton;
+import org.graalvm.visualvm.lib.ui.swing.GrayLabel;
 import org.openide.util.NbBundle;
 import org.openide.util.lookup.ServiceProvider;
 
@@ -86,7 +86,8 @@ import org.openide.util.lookup.ServiceProvider;
 })
 public class JavaObjectsView extends HeapViewerFeature {
     
-    private static final TreeTableView.ColumnConfiguration CCONF_CLASS = new TreeTableView.ColumnConfiguration(DataType.COUNT, null, DataType.COUNT, SortOrder.DESCENDING, Boolean.FALSE);
+    private static final TreeTableView.ColumnConfiguration CCONF_CLASS = new TreeTableView.ColumnConfiguration(DataType.COUNT, DataType.GCROOTS, DataType.COUNT, SortOrder.DESCENDING, Boolean.FALSE);
+    private static final TreeTableView.ColumnConfiguration CCONF_GCROOT = new TreeTableView.ColumnConfiguration(DataType.GCROOTS, null, DataType.GCROOTS, SortOrder.DESCENDING, Boolean.TRUE);
     private static final TreeTableView.ColumnConfiguration CCONF_INSTANCE = new TreeTableView.ColumnConfiguration(null, DataType.COUNT, DataType.OWN_SIZE, SortOrder.DESCENDING, null);
     
     private static final TreeTableView.ColumnConfiguration CCONF_PRES1 = new TreeTableView.ColumnConfiguration(DataType.COUNT, null, DataType.COUNT, SortOrder.DESCENDING, Boolean.TRUE);
@@ -444,8 +445,21 @@ public class JavaObjectsView extends HeapViewerFeature {
                 // invoked also from constructor: super(aggregation.getIcon(), selected)
                 // in this case aggregation is still null, ignore the event...
                 if (e.getStateChange() == ItemEvent.SELECTED && aggregation != null) {
-                    TreeTableView.ColumnConfiguration cconf = Aggregation.INSTANCES.equals(aggregation) ?
-                                                              CCONF_INSTANCE : CCONF_CLASS;
+                    TreeTableView.ColumnConfiguration cconf;
+                    switch (aggregation) {
+                        case INSTANCES:
+                            cconf = CCONF_INSTANCE;
+                            break;
+                        case CLASSES:
+                        case PACKAGES:
+                            cconf = CCONF_CLASS;
+                            break;
+                        case TYPES:
+                            cconf = CCONF_GCROOT;
+                            break;
+                        default:
+                            throw new IllegalArgumentException(aggregation.toString());
+                    }
                     setAggregation(aggregation, cconf);
                 }
             }
