@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,6 +24,12 @@
  */
 package org.graalvm.visualvm.heapviewer.java.impl;
 
+import java.net.URL;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 import org.graalvm.visualvm.heapviewer.HeapContext;
 import org.graalvm.visualvm.heapviewer.java.ClassNode;
 import org.graalvm.visualvm.heapviewer.java.InstanceNode;
@@ -33,12 +39,6 @@ import org.graalvm.visualvm.heapviewer.java.ThreadNode;
 import org.graalvm.visualvm.heapviewer.model.HeapViewerNode;
 import org.graalvm.visualvm.heapviewer.model.RootNode;
 import org.graalvm.visualvm.heapviewer.utils.HeapUtils;
-import java.net.URL;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
 import org.graalvm.visualvm.lib.jfluid.heap.GCRoot;
 import org.graalvm.visualvm.lib.jfluid.heap.Heap;
 import org.graalvm.visualvm.lib.jfluid.heap.Instance;
@@ -66,15 +66,26 @@ import org.openide.util.NbBundle;
 class JavaThreadsProvider {
     
     private static final String OPEN_THREADS_URL = "file:/stackframe/";     // NOI18N
+    private static final String LOCAL_VARIABLE = Bundle.JavaThreadsProvider_LocalVariable();
+    private static final String JNI_LOCAL = Bundle.JavaThreadsProvider_JniLocal();
+
     
-    
-    static String getThreadName(Heap heap, Instance instance) {
-        String threadName = getThreadInstanceName(heap, instance);
+    static String getThreadName(Instance instance) {
+        String threadName = getThreadInstanceName(instance);
+        Long threadId = (Long)instance.getValueOfField("tid");    // NOI18N
         Boolean daemon = (Boolean)instance.getValueOfField("daemon"); // NOI18N
         Integer priority = (Integer)instance.getValueOfField("priority"); // NOI18N
-        Long threadId = (Long)instance.getValueOfField("tid");    // NOI18N
         Integer threadStatus = (Integer)instance.getValueOfField("threadStatus"); // NOI18N
 
+        if (daemon == null) {
+            Instance holder = (Instance)instance.getValueOfField("holder");  // NOI18N
+            if (holder != null) {
+                daemon = (Boolean)holder.getValueOfField("daemon"); // NOI18N
+                priority = (Integer)holder.getValueOfField("priority"); // NOI18N
+                threadStatus = (Integer)holder.getValueOfField("threadStatus"); // NOI18N
+            }
+        }
+
         String tName = "\"" + threadName + "\"" + (daemon.booleanValue() ? " daemon" : "") + " prio=" + priority; // NOI18N
         if (threadId != null) tName += " tid=" + threadId; // NOI18N
         if (threadStatus != null) tName += " " + toThreadState(threadStatus.intValue()); // NOI18N
@@ -136,7 +147,7 @@ class JavaThreadsProvider {
                     StackTraceElement stack[] = threadRoot.getStackTrace();
                     Map<Integer,List<GCRoot>> localsMap = javaFrameMap.get(threadRoot);
 
-                    String tName = JavaThreadsProvider.getThreadName(heap, threadInstance);
+                    String tName = JavaThreadsProvider.getThreadName(threadInstance);
 
                     final List<HeapViewerNode> stackFrameNodes = new ArrayList();
                     ThreadNode threadNode = new ThreadNode(tName, threadRoot.equals(oome), threadInstance) {
@@ -157,9 +168,9 @@ class JavaThreadsProvider {
                                         if (localInstance != null) {
                                             String text = "";
                                             if (GCRoot.JAVA_FRAME.equals(local.getKind())) {
-                                                text = Bundle.JavaThreadsProvider_LocalVariable();
+                                                text = LOCAL_VARIABLE;
                                             } else if (GCRoot.JNI_LOCAL.equals(local.getKind())) {
-                                                text = Bundle.JavaThreadsProvider_JniLocal();
+                                                text = JNI_LOCAL;
                                             }
                                             localVariableNodes.add(new LocalObjectNode(localInstance, text));
                                         } else {
@@ -198,13 +209,14 @@ class JavaThreadsProvider {
         JavaClass javaClassClass = heap.getJavaClassByName(Class.class.getName());
         // Use this to enable VisualVM color scheme for threads dumps:
         // sw.append("<pre style='color: #cc3300;'>"); // NOI18N
+        sb.append("<head><style>span.g {color: #666666;}</style></head>");
         sb.append("<pre>"); // NOI18N
         for (GCRoot root : roots) {
             if(root.getKind().equals(GCRoot.THREAD_OBJECT)) {
                 ThreadObjectGCRoot threadRoot = (ThreadObjectGCRoot)root;
                 Instance threadInstance = threadRoot.getInstance();
                 if (threadInstance != null) {
-                    String threadName = JavaThreadsProvider.getThreadName(heap, threadInstance);
+                    String threadName = JavaThreadsProvider.getThreadName(threadInstance);
                     StackTraceElement stack[] = threadRoot.getStackTrace();
                     Map<Integer,List<GCRoot>> localsMap = javaFrameMap.get(threadRoot);
                     String style=""; // NOI18N
@@ -251,11 +263,11 @@ class JavaThreadsProvider {
                                         if (localInstance != null) {
                                             String text = "";
                                             if (GCRoot.JAVA_FRAME.equals(local.getKind())) {
-                                                text = Bundle.JavaThreadsProvider_LocalVariable();
+                                                text = LOCAL_VARIABLE;
                                             } else if (GCRoot.JNI_LOCAL.equals(local.getKind())) {
-                                                text = Bundle.JavaThreadsProvider_JniLocal();
+                                                text = JNI_LOCAL;
                                             }
-                                            sb.append("       <span style=\"color: #666666\">" + text + ":</span> ").append(HeapUtils.instanceToHtml(localInstance, false, heap, javaClassClass)).append("<br>"); // NOI18N
+                                            sb.append("       <span class=\"g\">" + text + ":</span> ").append(HeapUtils.instanceToHtml(localInstance, false, javaClassClass)).append("<br>"); // NOI18N
                                         } else {
                                             String text = "";
                                             if (GCRoot.JAVA_FRAME.equals(local.getKind())) {
@@ -263,7 +275,7 @@ class JavaThreadsProvider {
                                             } else if (GCRoot.JNI_LOCAL.equals(local.getKind())) {
                                                 text = Bundle.JavaThreadsProvider_UnknownJniLocal();
                                             }
-                                            sb.append("       <span style=\"color: #666666\">" + text + "</span><br>"); // NOI18N
+                                            sb.append("       <span class=\"g\">" + text + "</span><br>"); // NOI18N
                                         }
                                     }
                                 }
@@ -282,10 +294,10 @@ class JavaThreadsProvider {
     }
     
     
-    private static String getThreadInstanceName(Heap heap, Instance threadInstance) {
+    private static String getThreadInstanceName(Instance threadInstance) {
         Object threadName = threadInstance.getValueOfField("name");  // NOI18N
         if (threadName == null) return "*null*"; // NOI18N
-        return DetailsSupport.getDetailsString((Instance)threadName, heap);
+        return DetailsSupport.getDetailsString((Instance)threadName);
     }
     
     private static Map<ThreadObjectGCRoot,Map<Integer,List<GCRoot>>> computeJavaFrameMap(Collection<GCRoot> roots) {
