@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,48 +25,57 @@
 
 package org.graalvm.visualvm.heapviewer.oql;
 
-import org.graalvm.visualvm.core.ui.components.ScrollableContainer;
 import java.awt.BorderLayout;
 import java.awt.CardLayout;
 import java.awt.Color;
 import java.awt.Component;
+import java.awt.Container;
+import java.awt.Dialog;
 import java.awt.Dimension;
+import java.awt.GridBagConstraints;
+import java.awt.GridBagLayout;
+import java.awt.Insets;
 import java.awt.event.ActionEvent;
+import java.awt.event.ActionListener;
 import java.awt.event.ItemEvent;
 import java.net.URL;
+import java.text.Format;
+import java.text.NumberFormat;
 import java.util.List;
+import java.util.Set;
+import java.util.TreeSet;
+import javax.swing.AbstractAction;
+import javax.swing.Action;
 import javax.swing.BorderFactory;
 import javax.swing.BoundedRangeModel;
 import javax.swing.ButtonGroup;
 import javax.swing.DefaultBoundedRangeModel;
+import javax.swing.Icon;
 import javax.swing.JButton;
+import javax.swing.JComboBox;
 import javax.swing.JComponent;
 import javax.swing.JLabel;
+import javax.swing.JList;
 import javax.swing.JPanel;
+import javax.swing.JPopupMenu;
 import javax.swing.JProgressBar;
+import javax.swing.JTabbedPane;
 import javax.swing.JToggleButton;
+import javax.swing.JToolBar;
+import javax.swing.KeyStroke;
+import javax.swing.ListCellRenderer;
 import javax.swing.SortOrder;
 import javax.swing.SwingUtilities;
 import javax.swing.UIManager;
 import javax.swing.plaf.basic.BasicSplitPaneDivider;
 import javax.swing.plaf.basic.BasicSplitPaneUI;
-import org.graalvm.visualvm.lib.jfluid.heap.Heap;
-import org.graalvm.visualvm.lib.jfluid.heap.Instance;
-import org.graalvm.visualvm.lib.jfluid.heap.JavaClass;
-import org.graalvm.visualvm.lib.ui.UIUtils;
-import org.graalvm.visualvm.lib.ui.components.JExtendedSplitPane;
-import org.graalvm.visualvm.lib.ui.components.ProfilerToolbar;
-import org.graalvm.visualvm.lib.ui.swing.GrayLabel;
-import org.graalvm.visualvm.lib.profiler.api.ProfilerDialogs;
-import org.graalvm.visualvm.lib.profiler.api.icons.GeneralIcons;
-import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
-import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
-import org.graalvm.visualvm.lib.profiler.heapwalk.ui.icons.HeapWalkerIcons;
+import org.graalvm.visualvm.core.VisualVM;
+import org.graalvm.visualvm.core.ui.components.ScrollableContainer;
 import org.graalvm.visualvm.heapviewer.HeapContext;
 import org.graalvm.visualvm.heapviewer.java.ClassNode;
+import org.graalvm.visualvm.heapviewer.java.InstanceNode;
 import org.graalvm.visualvm.heapviewer.model.DataType;
 import org.graalvm.visualvm.heapviewer.model.HeapViewerNode;
-import org.graalvm.visualvm.heapviewer.java.InstanceNode;
 import org.graalvm.visualvm.heapviewer.model.HeapViewerNodeFilter;
 import org.graalvm.visualvm.heapviewer.model.Progress;
 import org.graalvm.visualvm.heapviewer.model.RootNode;
@@ -77,30 +86,21 @@ import org.graalvm.visualvm.heapviewer.ui.HeapViewerFeature;
 import org.graalvm.visualvm.heapviewer.ui.PluggableTreeTableView;
 import org.graalvm.visualvm.heapviewer.ui.TreeTableViewColumn;
 import org.graalvm.visualvm.heapviewer.utils.HeapUtils;
-import java.awt.Container;
-import java.awt.Dialog;
-import java.awt.GridBagConstraints;
-import java.awt.GridBagLayout;
-import java.awt.Insets;
-import java.awt.event.ActionListener;
-import java.text.Format;
-import java.text.NumberFormat;
-import java.util.Set;
-import java.util.TreeSet;
-import javax.swing.AbstractAction;
-import javax.swing.Action;
-import javax.swing.Icon;
-import javax.swing.JComboBox;
-import javax.swing.JList;
-import javax.swing.JPopupMenu;
-import javax.swing.JTabbedPane;
-import javax.swing.JToolBar;
-import javax.swing.ListCellRenderer;
-import org.graalvm.visualvm.core.VisualVM;
+import org.graalvm.visualvm.lib.jfluid.heap.Heap;
+import org.graalvm.visualvm.lib.jfluid.heap.Instance;
+import org.graalvm.visualvm.lib.jfluid.heap.JavaClass;
+import org.graalvm.visualvm.lib.profiler.api.ProfilerDialogs;
+import org.graalvm.visualvm.lib.profiler.api.icons.GeneralIcons;
+import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
 import org.graalvm.visualvm.lib.profiler.api.icons.LanguageIcons;
-import org.netbeans.api.options.OptionsDisplayer;
-import org.graalvm.visualvm.lib.profiler.heapwalk.OQLSupport;
+import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
+import org.graalvm.visualvm.lib.profiler.heapwalk.ui.icons.HeapWalkerIcons;
 import org.graalvm.visualvm.lib.profiler.oql.engine.api.OQLEngine;
+import org.graalvm.visualvm.lib.ui.UIUtils;
+import org.graalvm.visualvm.lib.ui.components.JExtendedSplitPane;
+import org.graalvm.visualvm.lib.ui.components.ProfilerToolbar;
+import org.graalvm.visualvm.lib.ui.swing.GrayLabel;
+import org.netbeans.api.options.OptionsDisplayer;
 import org.netbeans.modules.autoupdate.ui.api.PluginManager;
 import org.openide.DialogDescriptor;
 import org.openide.DialogDisplayer;
@@ -121,7 +121,7 @@ import org.openide.windows.TopComponent;
     "OQLConsoleView_ViewName=Results",
     "OQLConsoleView_OQLQuery=OQL Query:",
     "OQLConsoleView_RunAction=Run",
-    "OQLConsoleView_RunActionTooltip=Execute OQL script",
+    "OQLConsoleView_RunActionTooltip=Execute OQL script - Ctrl+R",
     "OQLConsoleView_CancelAction=Cancel",
     "OQLConsoleView_CancelActionTooltip=Cancel OQL script execution",
     "OQLConsoleView_LoadAction=Load Script",
@@ -215,7 +215,7 @@ public class OQLConsoleView extends HeapViewerFeature {
     
     private boolean queryValid;
     
-    private OQLSupport.Query currentQuery;
+    private OQLQuery currentQuery;
     
     
     public OQLConsoleView(HeapContext context, HeapViewerActions actions) {
@@ -314,7 +314,7 @@ public class OQLConsoleView extends HeapViewerFeature {
                     };
                     
                     TreeTableViewColumn[] ownColumns = new TreeTableViewColumn[] {
-                        new TreeTableViewColumn.Name(heap),
+                        new TreeTableViewColumn.Name(),
                         new TreeTableViewColumn.Count(heap, false, false),
                         new TreeTableViewColumn.OwnSize(heap, true, true),
                         new TreeTableViewColumn.RetainedSize(heap, true, false)
@@ -352,14 +352,7 @@ public class OQLConsoleView extends HeapViewerFeature {
 //                            toolbar.add(new GrayLabel(Bundle.OQLConsoleView_OQLQuery()));
 //                            toolbar.addSpace(2);
 
-                            runAction = new AbstractAction(Bundle.OQLConsoleView_RunAction(), Icons.getIcon(GeneralIcons.START)) {
-                                {
-                                    putValue(Action.SHORT_DESCRIPTION, Bundle.OQLConsoleView_RunActionTooltip());
-                                }
-                                public void actionPerformed(ActionEvent e) {
-                                    executeQuery();
-                                }
-                            };
+                            runAction = new RunAction();
 
                             JButton runButton = new JButton(runAction) {
                                 public Dimension getPreferredSize() {
@@ -396,7 +389,7 @@ public class OQLConsoleView extends HeapViewerFeature {
                                     if (e.getSource() instanceof JComponent) {
                                         JPopupMenu p = new JPopupMenu();
                                         OQLQueries.instance().populateLoadQuery(p, currentQuery, new OQLQueries.Handler() {
-                                            protected void querySelected(OQLSupport.Query query) {
+                                            protected void querySelected(OQLQuery query) {
                                                 currentQuery = query;
                                                 if (editor != null) editor.setScript(currentQuery.getScript());
                                             }
@@ -423,7 +416,7 @@ public class OQLConsoleView extends HeapViewerFeature {
                                     if (e.getSource() instanceof JComponent) {
                                         JPopupMenu p = new JPopupMenu();
                                         OQLQueries.instance().populateSaveQuery(p, currentQuery, editor.getScript(), new OQLQueries.Handler() {
-                                            protected void querySelected(OQLSupport.Query query) {
+                                            protected void querySelected(OQLQuery query) {
                                                 currentQuery = query;
                                                 editor.clearChanged();
                                                 
@@ -649,7 +642,10 @@ public class OQLConsoleView extends HeapViewerFeature {
                                 parent.repaint();
                             }
                             
-                            toolbar.getComponent().repaint();
+                            JComponent toolbarComp = toolbar.getComponent();
+                            setShortcut(runAction, toolbarComp);
+                            setShortcut(runAction, component);
+                            toolbarComp.repaint();
 
                             updateUIState();
                         }
@@ -661,6 +657,13 @@ public class OQLConsoleView extends HeapViewerFeature {
         });
     }
     
+    private void setShortcut(Action a, JComponent jc) {
+        Object actionName = a.getValue(Action.ACTION_COMMAND_KEY);
+        KeyStroke shortcut = (KeyStroke) a.getValue(Action.ACCELERATOR_KEY);
+        jc.getInputMap(JComponent.WHEN_ANCESTOR_OF_FOCUSED_COMPONENT).put(shortcut, actionName);
+        jc.getActionMap().put(actionName, a);
+    }
+
     private void notifyFailedOQL(final boolean available) {
         SwingUtilities.invokeLater(new Runnable() {
             @Override
@@ -834,7 +837,22 @@ public class OQLConsoleView extends HeapViewerFeature {
         return null;
     }
     
-    
+    private final class RunAction extends AbstractAction {
+        private static final String ACTION_NAME  = "runScript_Action";     // NOI18N
+        private final KeyStroke shortcut = KeyStroke.getKeyStroke("ctrl R");  // NOI18N
+
+        private RunAction() {
+            super(Bundle.OQLConsoleView_RunAction(), Icons.getIcon(GeneralIcons.START));
+            putValue(Action.SHORT_DESCRIPTION, Bundle.OQLConsoleView_RunActionTooltip());
+            putValue(Action.ACTION_COMMAND_KEY, ACTION_NAME);
+            putValue(Action.ACCELERATOR_KEY, shortcut);
+        }
+
+        public void actionPerformed(ActionEvent e) {
+            executeQuery();
+        }
+    }
+
     private class EditorView extends JPanel {
         
         EditorView(OQLEditorComponent editor) {
@@ -871,7 +889,7 @@ public class OQLConsoleView extends HeapViewerFeature {
     }
     
     
-    private class ResultsView extends JPanel {
+    private static class ResultsView extends JPanel {
         
         ResultsView(JComponent results) {
             super(new BorderLayout());
