@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -110,8 +110,7 @@ public class JmxApplicationProvider {
     
     
     private volatile boolean trackingNewHosts;
-    private Map<String, Set<Storage>> persistedApplications =
-            new HashMap<String, Set<Storage>>();
+    private Map<String, Set<Storage>> persistedApplications = new HashMap<>();
     
 
     private static boolean isLocalHost(String hostname) throws IOException {
@@ -344,15 +343,15 @@ public class JmxApplicationProvider {
                 if ('/' == urlPath.charAt(0)) { // NOI18N
                     hostname = "localhost"; // NOI18N
                 } else if ('[' == urlPath.charAt(0)) { // IPv6 address  // NOI18N
-                    int closingSquareBracketIndex = urlPath.indexOf("]"); // NOI18N
+                    int closingSquareBracketIndex = urlPath.indexOf(']'); // NOI18N
                     if (closingSquareBracketIndex == -1) {
                         hostname = null;
                     } else {
                         hostname = urlPath.substring(0, closingSquareBracketIndex + 1);
                     }
                 } else {
-                    int colonIndex = urlPath.indexOf(":"); // NOI18N
-                    int slashIndex = urlPath.indexOf("/"); // NOI18N
+                    int colonIndex = urlPath.indexOf(':'); // NOI18N
+                    int slashIndex = urlPath.indexOf('/'); // NOI18N
                     int min = Math.min(colonIndex, slashIndex); // NOTE: can be -1!!!
                     if (min == -1) {
                         min = 0;
@@ -388,7 +387,7 @@ public class JmxApplicationProvider {
                 Storage storage = new Storage(file, PROPERTIES_FILE);
                 Set<Storage> storageSet = persistedApplications.get(storage.getCustomProperty(PROPERTY_HOSTNAME));
                 if (storageSet == null) {
-                    storageSet = new HashSet<Storage>();
+                    storageSet = new HashSet<>();
                     persistedApplications.put(storage.getCustomProperty(PROPERTY_HOSTNAME), storageSet);
                 }
                 storageSet.add(storage);
@@ -398,8 +397,8 @@ public class JmxApplicationProvider {
         DataChangeListener<Host> dataChangeListener = new DataChangeListener<Host>() {
 
             public synchronized void dataChanged(DataChangeEvent<Host> event) {
-                final Set<String> failedAppsN = Collections.synchronizedSet(new HashSet());
-                final Set<Storage> failedAppsS = Collections.synchronizedSet(new HashSet());
+                final Set<String> failedAppsN = Collections.synchronizedSet(new HashSet<>());
+                final Set<Storage> failedAppsS = Collections.synchronizedSet(new HashSet<>());
                 Set<Host> hosts = event.getAdded();
                 for (Host host : hosts) {
                     String hostName = host.getHostName();
@@ -419,7 +418,7 @@ public class JmxApplicationProvider {
                         };
                         
                         final AtomicInteger counter = new AtomicInteger(storageSetSize);
-                        final Collection<JmxApplication> persistentApps = Collections.synchronizedList(new ArrayList());
+                        final Collection<JmxApplication> persistentApps = Collections.synchronizedList(new ArrayList<>());
                         RequestProcessor processor = new RequestProcessor("JMX Persistence Processor", Math.min(storageSetSize, 10)); // NOI18N
                         
                         for (final Storage storage : storageSet) {
@@ -490,12 +489,12 @@ public class JmxApplicationProvider {
                 if (b == null) {
                     JPanel messagePanel = new JPanel(new BorderLayout(5, 5));
                     messagePanel.add(new JLabel(NbBundle.getMessage(JmxApplicationProvider.class, "MSG_Unresolved_JMX")), BorderLayout.NORTH); // NOI18N
-                    JList list = new JList(failedHostsN.toArray());
+                    JList<Object> list = new JList<>(failedHostsN.toArray());
                     list.setVisibleRowCount(4);
                     messagePanel.add(new JScrollPane(list), BorderLayout.CENTER);
                     JCheckBox dnsa = new JCheckBox();
                     Mnemonics.setLocalizedText(dnsa, NbBundle.getMessage(JmxApplicationProvider.class, "LBL_RememberAction")); // NOI18N
-                    dnsa.setToolTipText(NbBundle.getMessage(JmxApplicationProvider.class, "TTP_RememberAction")); // NOI18N
+                    dnsa.setToolTipText(NbBundle.getMessage(JmxApplicationProvider.class, "TTP_RememberAction", VisualVM.getInstance().getOptionsHandle())); // NOI18N
                     JPanel p = new JPanel(new BorderLayout());
                     p.setBorder(BorderFactory.createEmptyBorder(10, 0, 0, 20));
                     p.add(dnsa, BorderLayout.WEST);
@@ -538,8 +537,8 @@ public class JmxApplicationProvider {
     
     private static class JMXException extends Exception {
         private final boolean isConfig;
-        public JMXException(boolean config, String message) { super(message); isConfig = config; }
-        public JMXException(boolean config, String message, Throwable cause) { super(message,cause); isConfig = config; }
+        JMXException(boolean config, String message) { super(message); isConfig = config; }
+        JMXException(boolean config, String message, Throwable cause) { super(message,cause); isConfig = config; }
         public boolean isConfig() { return isConfig; }
     }
     
