@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.jfluid.classfile;
@@ -56,7 +38,7 @@ import org.graalvm.visualvm.lib.jfluid.utils.MiscUtils;
 
 
 /**
- * A collection of several static methods for general class file reading functionality. Allows to set
+ * A collection of several methods for general class file reading functionality. Allows to set
  * a class path, read a class from class path, generate a class that does not have a .class file (such
  * as an array class), etc. It also keeps track of classes ever loaded by it, and allows one to iterate
  * over these classes.
@@ -64,7 +46,7 @@ import org.graalvm.visualvm.lib.jfluid.utils.MiscUtils;
  * @author Tomas Hurka
  * @author Misha Dmitirev
  */
-public abstract class ClassRepository implements CommonConstants {
+public class ClassRepository implements CommonConstants {
     //~ Inner Classes ------------------------------------------------------------------------------------------------------------
 
     // ------------------------ Method-class-source related stuff --------------------------------
@@ -100,22 +82,26 @@ public abstract class ClassRepository implements CommonConstants {
         }
     }
 
-    //~ Static fields/initializers -----------------------------------------------------------------------------------------------
+    //~ fields/initializers -----------------------------------------------------------------------------------------------
 
     // The below class file location signals to ClassFileCache that the class file should have been already supplied by the VM.
     static final String LOCATION_VMSUPPLIED = "<VM_SUPPLIED>"; // NOI18N
-    private static ClassPath classPath;
-    private static Hashtable classes;
-    private static Set notFoundClasses;
-    private static Map definingClassLoaderMap;
+    private ClassPath classPath;
+    private Hashtable classes;
+    private Set notFoundClasses;
+    private Map definingClassLoaderMap;
 
-    static {
-        clearCache();
+    //~ Constructors -------------------------------------------------------------------------------------------------------------
+
+    public ClassRepository() {
+        classes = new Hashtable();
+        notFoundClasses = new HashSet();
+        definingClassLoaderMap = new HashMap();
     }
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
 
-    public static List getAllClassVersions(String className) {
+    public List getAllClassVersions(String className) {
         className = className.replace('.', '/').intern(); // NOI18N
 
         Object entry = classes.get(className);
@@ -136,7 +122,7 @@ public abstract class ClassRepository implements CommonConstants {
         }
     }
 
-    public static Enumeration getClassEnumerationWithAllVersions() {
+    public Enumeration getClassEnumerationWithAllVersions() {
         class ClassesEnumeration implements Enumeration {
             private Enumeration baseEnum;
             private Object nextElement;
@@ -191,7 +177,7 @@ public abstract class ClassRepository implements CommonConstants {
         return new ClassesEnumeration(classes.elements());
     }
 
-    public static ClassPath getClassPath() {
+    public ClassPath getClassPath() {
         return classPath;
     }
 
@@ -220,7 +206,7 @@ public abstract class ClassRepository implements CommonConstants {
         return res;
     }
 
-    public static CodeRegionBCI getMethodForSourceRegion(ClassInfo clazz, int startLine, int endLine)
+    public CodeRegionBCI getMethodForSourceRegion(ClassInfo clazz, int startLine, int endLine)
                                                   throws ClassNotFoundException, IOException, BadLocationException {
         if (startLine > endLine) {
             return null; // Just in case...
@@ -341,7 +327,7 @@ public abstract class ClassRepository implements CommonConstants {
         return new CodeRegionBCI(clazz.getName(), methodName, methodSignature, 0, clazz.getMethodBytecode(idx).length - 1);
     }
 
-    public static void addClassInfo(BaseClassInfo pci) {
+    public void addClassInfo(BaseClassInfo pci) {
         BaseClassInfo singleExistingClazzOrPCI;
         SameNameClassGroup classGroup;
         String className = pci.getName();
@@ -366,19 +352,19 @@ public abstract class ClassRepository implements CommonConstants {
     }
 
     /** Adds a VM-supplied class file to the class file cache, but not to this repository's hashtable yet. */
-    public static void addVMSuppliedClassFile(String className, int classLoaderId, byte[] buf) {
+    public void addVMSuppliedClassFile(String className, int classLoaderId, byte[] buf) {
         assert buf != null && buf.length > 0;
         addVMSuppliedClassFile(className, classLoaderId, buf, null, null);
     }
     
     /** Adds a VM-supplied class file to the class file cache, but not to this repository's hashtable yet. */
-    public static void addVMSuppliedClassFile(String className, int classLoaderId, byte[] buf, String superClassName, String[] interfaceNames) {
-        ClassFileCache.getDefault().addVMSuppliedClassFile(className, classLoaderId, buf);
+    public void addVMSuppliedClassFile(String className, int classLoaderId, byte[] buf, String superClassName, String[] interfaceNames) {
+        classPath.addVMSuppliedClassFile(className, classLoaderId, buf);
         if (buf != null && buf.length == 0) {
             // register lazy dynamic class
             try {
                 String location = getClassFileLoc(classLoaderId);
-                DynamicClassInfo lazyClass = new LazyDynamicClassInfo(className, classLoaderId, location, superClassName, interfaceNames);
+                DynamicClassInfo lazyClass = new LazyDynamicClassInfo(classPath, className, classLoaderId, location, superClassName, interfaceNames);
                 addClassInfo(lazyClass);
             } catch (IOException ex) { // this should not happen
                 Logger.getLogger(ClassRepository.class.getName()).log(Level.SEVERE, null, ex);
@@ -387,7 +373,7 @@ public abstract class ClassRepository implements CommonConstants {
     }
 
     /** Should be called after profiling finishes to cleanup any static data, close opened files, etc. */
-    public static void cleanup() {
+    public void cleanup() {
         clearCache();
 
         if (classPath != null) {
@@ -397,9 +383,9 @@ public abstract class ClassRepository implements CommonConstants {
     }
 
     /** Will reset any cached data, will not reset data pertinent to session in progress */
-    public static void clearCache() {
+    public void clearCache() {
         classes = new Hashtable();
-        ClassFileCache.resetDefaultCache();
+//        ClassFileCache.resetDefaultCache();
         notFoundClasses = new HashSet();
         definingClassLoaderMap = new HashMap();
     }
@@ -412,7 +398,7 @@ public abstract class ClassRepository implements CommonConstants {
      * @param workingDir            working directory, needed in case the given paths are in the local form
      * @param classPaths            the 3 elements should be the user, extension, and boot class paths, respectively
      */
-    public static void initClassPaths(String workingDir, String[] classPaths) {
+    public void initClassPaths(String workingDir, String[] classPaths) {
         List userClassPathElementList = MiscUtils.getPathComponents(classPaths[0], true, workingDir);
         List bootClassPathElementList = MiscUtils.getPathComponents(classPaths[2], true, workingDir);
 
@@ -437,8 +423,8 @@ public abstract class ClassRepository implements CommonConstants {
                 continue;
             }
 
-            for (int i = 0; i < extensions.length; i++) {
-                String extJar = extDir.getAbsolutePath() + File.separatorChar + extensions[i];
+            for (String extension : extensions) {
+                String extJar = extDir.getAbsolutePath() + File.separatorChar + extension;
                 List allJarComponents = MiscUtils.getPathComponents(extJar,true,workingDir);
                 extClassPathElementList.addAll(allJarComponents);
             }
@@ -470,7 +456,7 @@ public abstract class ClassRepository implements CommonConstants {
      * Guaranteed to return a real class or null, but not a placeholder. Should not be called for special (array)
      * classes - there is lookupSpecialClass() for that.
      */
-    public static DynamicClassInfo lookupClass(String className, int classLoaderId)
+    public DynamicClassInfo lookupClass(String className, int classLoaderId)
                                         throws IOException, ClassFormatError {
         return lookupClass(className, classLoaderId, true);
     }
@@ -480,7 +466,7 @@ public abstract class ClassRepository implements CommonConstants {
      * return an instance of PlaceholderClassInfo. The rationale is that we may not ever need the real class for
      * className; and when we need it, lookupClass() above will deliver it.
      */
-    public static BaseClassInfo lookupClassOrCreatePlaceholder(String className, int classLoaderId) {
+    public BaseClassInfo lookupClassOrCreatePlaceholder(String className, int classLoaderId) {
         BaseClassInfo singleExistingClazzOrPCI = null;
         BaseClassInfo clazzOrPCI = null;
         SameNameClassGroup classGroup = null;
@@ -492,10 +478,10 @@ public abstract class ClassRepository implements CommonConstants {
 
             if (entry instanceof BaseClassInfo) {
                 singleExistingClazzOrPCI = (BaseClassInfo) entry;
-                clazzOrPCI = SameNameClassGroup.checkForCompatibility(singleExistingClazzOrPCI, classLoaderId);
+                clazzOrPCI = SameNameClassGroup.checkForCompatibility(this, singleExistingClazzOrPCI, classLoaderId);
             } else { // entry is a SameNameClassGroup
                 classGroup = (SameNameClassGroup) entry;
-                clazzOrPCI = classGroup.findCompatibleClass(classLoaderId);
+                clazzOrPCI = classGroup.findCompatibleClass(this, classLoaderId);
             }
 
             if (clazzOrPCI != null) { // Found compatible class or placeholder
@@ -528,7 +514,7 @@ public abstract class ClassRepository implements CommonConstants {
      * If there is no loaded class and allowExistingPlaceholder is true, also check for an existing placeholders.
      * Returns either a loaded class, or if allowed an existing placeholder, or null, but not a new placeholder.
      */
-    public static BaseClassInfo lookupLoadedClass(String className, int classLoaderId, boolean allowExistingPlaceholder) {
+    public BaseClassInfo lookupLoadedClass(String className, int classLoaderId, boolean allowExistingPlaceholder) {
         BaseClassInfo singleExistingClazzOrPCI = null;
         BaseClassInfo clazzOrPCI = null;
         className = className.replace('.', '/').intern(); // NOI18N
@@ -539,11 +525,11 @@ public abstract class ClassRepository implements CommonConstants {
 
             if (entry instanceof BaseClassInfo) {
                 singleExistingClazzOrPCI = (BaseClassInfo) entry;
-                clazzOrPCI = SameNameClassGroup.checkForCompatibility(singleExistingClazzOrPCI, classLoaderId);
+                clazzOrPCI = SameNameClassGroup.checkForCompatibility(this, singleExistingClazzOrPCI, classLoaderId);
             } else { // entry is a SameNameClassGroup
 
                 SameNameClassGroup classGroup = (SameNameClassGroup) entry;
-                clazzOrPCI = classGroup.findCompatibleClass(classLoaderId);
+                clazzOrPCI = classGroup.findCompatibleClass(this, classLoaderId);
             }
 
             if (clazzOrPCI != null) { // Found compatible class or placeholder
@@ -563,7 +549,7 @@ public abstract class ClassRepository implements CommonConstants {
      * Used only for special classes, such as array classes, that don't have a .class file on the class path. If a class
      * with the given name does not exist, a BaseClassInfo is created for it immediately.
      */
-    public static BaseClassInfo lookupSpecialClass(String className) {
+    public BaseClassInfo lookupSpecialClass(String className) {
         if (className.indexOf('.') != -1) { // NOI18N
             className = className.replace('.', '/').intern(); // NOI18N
         }
@@ -578,7 +564,7 @@ public abstract class ClassRepository implements CommonConstants {
         return clazz;
     }
 
-    static int getDefiningClassLoaderId(String className, int classLoaderId) {
+    int getDefiningClassLoaderId(String className, int classLoaderId) {
         String classId = className + "#" + classLoaderId; // NOI18N
         Integer loaderInt = (Integer) definingClassLoaderMap.get(classId);
 
@@ -599,20 +585,20 @@ public abstract class ClassRepository implements CommonConstants {
         return loader;
     }
 
-    private static CodeRegionBCI getMethodForSourceRegionInNestedClasses(ClassInfo clazz, int startLine, int endLine)
+    private CodeRegionBCI getMethodForSourceRegionInNestedClasses(ClassInfo clazz, int startLine, int endLine)
         throws ClassNotFoundException, IOException, ClassFormatError {
         String className = clazz.getName();
         String[] nestedClassNames = clazz.getNestedClassNames();
         int classNameLen = className.length();
 
         if (nestedClassNames != null) {
-            for (int i = 0; i < nestedClassNames.length; i++) {
-                if (!(nestedClassNames[i].startsWith(className) && (nestedClassNames[i].length() > classNameLen))) {
+            for (String nestedClassName : nestedClassNames) {
+                if (!(nestedClassName.startsWith(className) && (nestedClassName.length() > classNameLen))) {
                     continue;
                 }
 
                 try {
-                    ClassInfo nestedClass = lookupClass(nestedClassNames[i], clazz.getLoaderId());
+                    ClassInfo nestedClass = lookupClass(nestedClassName, clazz.getLoaderId());
 
                     if (nestedClass != null) {
                         CodeRegionBCI res = getMethodForSourceRegion(nestedClass, startLine, endLine);
@@ -632,13 +618,13 @@ public abstract class ClassRepository implements CommonConstants {
         return null;
     }
 
-    private static DynamicClassInfo checkForVMSuppliedClass(String className, int classLoaderId)
+    private DynamicClassInfo checkForVMSuppliedClass(String className, int classLoaderId)
                                                      throws IOException, ClassFormatError {
-        int realLoaderId = ClassFileCache.getDefault().hasVMSuppliedClassFile(className, classLoaderId);
+        int realLoaderId = classPath.hasVMSuppliedClassFile(className, classLoaderId);
 
         if (realLoaderId != -1) {
             String classFileLoc = getClassFileLoc(realLoaderId);
-            return new DynamicClassInfo(className, classLoaderId, classFileLoc);
+            return new DynamicClassInfo(classPath, className, classLoaderId, classFileLoc);
         } else {
             return null;
         }
@@ -648,7 +634,7 @@ public abstract class ClassRepository implements CommonConstants {
         return (LOCATION_VMSUPPLIED + realLoaderId).intern();
     }
 
-    private static DynamicClassInfo lookupClass(String className, int classLoaderId, boolean reportIfNotFound)
+    private DynamicClassInfo lookupClass(String className, int classLoaderId, boolean reportIfNotFound)
                                          throws IOException, ClassFormatError {
         BaseClassInfo singleExistingClazzOrPCI = null;
         BaseClassInfo clazzOrPCI;
@@ -661,10 +647,10 @@ public abstract class ClassRepository implements CommonConstants {
 
             if (entry instanceof BaseClassInfo) {
                 singleExistingClazzOrPCI = (BaseClassInfo) entry;
-                clazzOrPCI = SameNameClassGroup.checkForCompatibility(singleExistingClazzOrPCI, classLoaderId);
+                clazzOrPCI = SameNameClassGroup.checkForCompatibility(this, singleExistingClazzOrPCI, classLoaderId);
             } else { // entry is a SameNameClassGroup
                 classGroup = (SameNameClassGroup) entry;
-                clazzOrPCI = classGroup.findCompatibleClass(classLoaderId);
+                clazzOrPCI = classGroup.findCompatibleClass(this, classLoaderId);
             }
 
             if (clazzOrPCI != null) { // Found compatible class or placeholder
@@ -724,7 +710,7 @@ public abstract class ClassRepository implements CommonConstants {
         }
     }
 
-    private static DynamicClassInfo tryLoadRealClass(String className, int classLoaderId, boolean reportIfNotFound)
+    private DynamicClassInfo tryLoadRealClass(String className, int classLoaderId, boolean reportIfNotFound)
                                               throws IOException, ClassFormatError {
         DynamicClassInfo clazz = null;
         int loader = classLoaderId;
@@ -745,7 +731,7 @@ public abstract class ClassRepository implements CommonConstants {
             }
 
             // Try parent loader - in some cases a class can be initially requested with the loader of its subclass
-            loader = ClassLoaderTable.getParentLoader(loader);
+            loader = classPath.getClassLoaderTable().getParentLoader(loader);
         } while (loader >= 0);
 
         if (clazz == null) {
