@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.jfluid.instrumentation;
@@ -48,7 +30,6 @@ import java.util.ArrayList;
 import java.util.List;
 import org.graalvm.visualvm.lib.jfluid.ProfilerEngineSettings;
 import org.graalvm.visualvm.lib.jfluid.classfile.BaseClassInfo;
-import org.graalvm.visualvm.lib.jfluid.classfile.ClassLoaderTable;
 import org.graalvm.visualvm.lib.jfluid.classfile.ClassRepository;
 import org.graalvm.visualvm.lib.jfluid.client.ClientUtils.SourceCodeSelection;
 import org.graalvm.visualvm.lib.jfluid.client.RuntimeProfilingPoint;
@@ -67,7 +48,7 @@ import org.graalvm.visualvm.lib.jfluid.wireprotocol.RootClassLoadedCommand;
 
 /**
  * A high-level interface to all method instrumentation operations.
- * <p/>
+ * <p>
  * Instrumentor subclasses find methods/classes to be instrumented.
  *
  * @author Tomas Hurka
@@ -89,6 +70,7 @@ public class Instrumentor implements CommonConstants {
     private ProfilingSessionStatus status;
     private RecursiveMethodInstrumentor ms;
     private RootMethods rootMethods;
+    private ClassRepository classRepo;
 
     // Data for the case of code region instrumentation
     private SourceCodeSelection savedSourceCodeSelection;
@@ -102,10 +84,12 @@ public class Instrumentor implements CommonConstants {
      * @param status   ProfilingSessionStatus used for profiling
      * @param settings Engine settings - same instance is reused for all profiling sessions, the settings are modified
      *                 each time before the session is started.
+     * @param repo     ClassRepository to access profiled classes
      */
-    public Instrumentor(ProfilingSessionStatus status, ProfilerEngineSettings settings) {
+    public Instrumentor(ClassRepository repo, ProfilingSessionStatus status, ProfilerEngineSettings settings) {
         this.status = status;
         this.settings = settings;
+        classRepo = repo;
     }
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
@@ -126,7 +110,7 @@ public class Instrumentor implements CommonConstants {
                 return -1;
             }
 
-            clazz = ClassRepository.lookupSpecialClass(className);
+            clazz = classRepo.lookupSpecialClass(className);
             if (clazz.getInstrClassId() == -1) {
                 clazz.setInstrClassId(oms.getNextClassId(className));
             }
@@ -134,7 +118,7 @@ public class Instrumentor implements CommonConstants {
             if (!filter.passes(className.replace('.', '/'))) { // NOI18N
                 return -1;
             }
-            clazz = ClassRepository.lookupClassOrCreatePlaceholder(className, classLoaderId);
+            clazz = classRepo.lookupClassOrCreatePlaceholder(className, classLoaderId);
         }
 
         if (clazz == null) {
@@ -171,8 +155,7 @@ public class Instrumentor implements CommonConstants {
             rootClassNames = new ArrayList();
         }
 
-        for (int i = 0; i < pps.length; i++) {
-            RuntimeProfilingPoint pp = pps[i];
+        for (RuntimeProfilingPoint pp : pps) {
             String className = pp.getClassName();
 
             if (!rootClassNames.contains(className)) {
@@ -214,11 +197,11 @@ public class Instrumentor implements CommonConstants {
             case INSTR_OBJECT_ALLOCATIONS:
             case INSTR_OBJECT_LIVENESS:
                 ms = null; // Free some memory
-                ret = (new MiscInstrumentationOps(status)).getOrigCodeForAllInstrumentedMethods();
+                ret = (new MiscInstrumentationOps(classRepo, status)).getOrigCodeForAllInstrumentedMethods();
 
                 break;
             case INSTR_CODE_REGION:
-                ret = (new MiscInstrumentationOps(status)).getOrigCodeForSingleInstrumentedMethod(rootMethods);
+                ret = (new MiscInstrumentationOps(classRepo, status)).getOrigCodeForSingleInstrumentedMethod(rootMethods);
 
                 break;
         }
@@ -246,10 +229,10 @@ public class Instrumentor implements CommonConstants {
             byte[] classFileBytes = clcmd.getClassFileBytes();
 
             if (classFileBytes != null) {
-                ClassRepository.addVMSuppliedClassFile(clcmd.getClassName().replace('.','/'), thisAndParentLoaderData[0], classFileBytes);
+                classRepo.addVMSuppliedClassFile(clcmd.getClassName().replace('.','/'), thisAndParentLoaderData[0], classFileBytes);
             }
 
-            ClassLoaderTable.addChildAndParent(thisAndParentLoaderData);
+            classRepo.getClassPath().getClassLoaderTable().addChildAndParent(thisAndParentLoaderData);
         } else if (cmd instanceof MethodLoadedCommand) {
             MethodLoadedCommand mcmd = (MethodLoadedCommand) cmd;
 
@@ -298,7 +281,7 @@ public class Instrumentor implements CommonConstants {
 
     public synchronized InstrumentMethodGroupResponse createInitialInstrumentMethodGroupResponse(RootClassLoadedCommand cmd)
         throws ClassNotFoundException, BadLocationException {
-        ClassLoaderTable.initTable(cmd.getParentLoaderIds());
+        classRepo.getClassPath().getClassLoaderTable().initTable(cmd.getParentLoaderIds());
 
         InstrumentMethodGroupResponse imgr = null;
 
@@ -335,7 +318,7 @@ public class Instrumentor implements CommonConstants {
      * It resets the internal data for loaded/instrumented classes etc.
      */
     public void resetPerVMInstanceData() {
-        ClassRepository.clearCache();
+        classRepo.clearCache();
     }
 
     private InstrumentMethodGroupResponse createFollowUpInstrumentMethodGroupResponseForCallGraph(Command cmd) {
@@ -443,15 +426,15 @@ public class Instrumentor implements CommonConstants {
 
         switch (settings.getInstrScheme()) {
             case INSTRSCHEME_LAZY:
-                ms = new RecursiveMethodInstrumentor1(status, settings);
+                ms = new RecursiveMethodInstrumentor1(classRepo, status, settings);
 
                 break;
             case INSTRSCHEME_EAGER:
-                ms = new RecursiveMethodInstrumentor2(status, settings);
+                ms = new RecursiveMethodInstrumentor2(classRepo, status, settings);
 
                 break;
             case INSTRSCHEME_TOTAL:
-                ms = new RecursiveMethodInstrumentor3(status, settings);
+                ms = new RecursiveMethodInstrumentor3(classRepo, status, settings);
 
                 break;
         }
@@ -468,14 +451,11 @@ public class Instrumentor implements CommonConstants {
     // ---------------------------------- Code region instrumentation ----------------------------------------------------
     private InstrumentMethodGroupResponse createInitialInstrumentMethodGroupResponseForCodeRegion(RootClassLoadedCommand rootLoaded)
         throws ClassNotFoundException, BadLocationException {
-        CodeRegionMethodInstrumentor.resetLoadedClassData();
-        ClassManager.storeClassFileBytesForCustomLoaderClasses(rootLoaded);
+        classRepo.clearCache();
 
-        crms = new CodeRegionMethodInstrumentor(status, savedSourceCodeSelection);
+        crms = new CodeRegionMethodInstrumentor(classRepo, status, savedSourceCodeSelection);
 
-        String[] loadedClasses = rootLoaded.getAllLoadedClassNames();
-        int[] loadedClassLoaderIds = rootLoaded.getAllLoadedClassLoaderIds();
-        Object[] ret = crms.getInitialInstrumentCodeRegionResponse(loadedClasses, loadedClassLoaderIds);
+        Object[] ret = crms.getInitialInstrumentCodeRegionResponse(rootLoaded);
 
         if (ret == null) {
             return new InstrumentMethodGroupResponse(null);
@@ -490,7 +470,7 @@ public class Instrumentor implements CommonConstants {
         //System.out.println("+++++++++ Received memory profiling instrumentation initialization event of type "
         // + instrType);
         //System.out.println("+++++++++ Number of target VM loaded classes: " + loadedClasses.length);
-        oms = new ObjLivenessMethodInstrumentor(status, settings, (instrType == INSTR_OBJECT_LIVENESS));
+        oms = new ObjLivenessMethodInstrumentor(classRepo, status, settings, (instrType == INSTR_OBJECT_LIVENESS));
 
         Object[] ret = oms.getInitialMethodsToInstrument(rootLoaded);
 
