@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.jfluid.instrumentation;
@@ -46,6 +28,7 @@ package org.graalvm.visualvm.lib.jfluid.instrumentation;
 import java.util.ArrayList;
 import org.graalvm.visualvm.lib.jfluid.ProfilerEngineSettings;
 import org.graalvm.visualvm.lib.jfluid.classfile.BaseClassInfo;
+import org.graalvm.visualvm.lib.jfluid.classfile.ClassRepository;
 import org.graalvm.visualvm.lib.jfluid.classfile.DynamicClassInfo;
 import org.graalvm.visualvm.lib.jfluid.classfile.PlaceholderClassInfo;
 import org.graalvm.visualvm.lib.jfluid.global.ProfilingSessionStatus;
@@ -67,7 +50,7 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
     protected class ReachableMethodPlaceholder2 extends ReachableMethodPlaceholder {
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
-        public ReachableMethodPlaceholder2(String refClassName, int classLoaderId) {
+        ReachableMethodPlaceholder2(String refClassName, int classLoaderId) {
             super(refClassName, classLoaderId);
         }
 
@@ -87,8 +70,8 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
 
     //~ Constructors -------------------------------------------------------------------------------------------------------------
 
-    public RecursiveMethodInstrumentor2(ProfilingSessionStatus status, ProfilerEngineSettings settings) {
-        super(status, settings);
+    public RecursiveMethodInstrumentor2(ClassRepository repo, ProfilingSessionStatus status, ProfilerEngineSettings settings) {
+        super(repo, status, settings);
     }
 
     //~ Methods ------------------------------------------------------------------------------------------------------------------
@@ -99,25 +82,25 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
         rootMethods = roots;
 
         // Check which root classes have already been loaded, and mark their root methods accordingly
-        for (int j = 0; j < loadedClassInfos.length; j++) {
-            if (loadedClassInfos[j] == null) {
+        for (DynamicClassInfo loadedClassInfo : loadedClassInfos) {
+            if (loadedClassInfo == null) {
                 continue; // Can this happen?
             }
 
-            markProfilingPonitForInstrumentation(loadedClassInfos[j]);
-            tryInstrumentSpawnedThreads(loadedClassInfos[j]); // This only checks for Runnable.run()
+            markProfilingPonitForInstrumentation(loadedClassInfo);
+            tryInstrumentSpawnedThreads(loadedClassInfo); // This only checks for Runnable.run()
 
             for (int rIdx = 0; rIdx < rootMethods.classNames.length; rIdx++) {
                 String rootClassName = rootMethods.classNames[rIdx];
                 boolean isMatch = false;
 
                 if (rootMethods.classesWildcard[rIdx]) {
-                    if (Wildcards.matchesWildcard(rootClassName, loadedClassInfos[j].getName())) {
+                    if (Wildcards.matchesWildcard(rootClassName, loadedClassInfo.getName())) {
                         //            System.out.println("(Instrumentor 2) Matched package wildcard - " + rootClassName);
                         isMatch = true;
                     }
                 } else {
-                    if (loadedClassInfos[j].getName().equals(rootClassName)) { // precise match
+                    if (loadedClassInfo.getName().equals(rootClassName)) { // precise match
                         isMatch = true;
                     }
                 }
@@ -126,21 +109,21 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
 
                     if (Wildcards.isPackageWildcard(rootClassName) || Wildcards.isMethodWildcard(rootMethods.methodNames[rIdx])) {
                         if (rootMethods.markerMethods[rIdx]) {
-                            markAllMethodsMarker(loadedClassInfos[j]);
+                            markAllMethodsMarker(loadedClassInfo);
                         } else {
-                            markAllMethodsRoot(loadedClassInfos[j]);
+                            markAllMethodsRoot(loadedClassInfo);
                         }
 
-                        String[] methodNames = loadedClassInfos[j].getMethodNames();
-                        String[] signatures = loadedClassInfos[j].getMethodSignatures();
+                        String[] methodNames = loadedClassInfo.getMethodNames();
+                        String[] signatures = loadedClassInfo.getMethodSignatures();
 
                         for (int methodIdx = 0; methodIdx < methodNames.length; methodIdx++) {
-                            checkAndScanMethod(loadedClassInfos[j], methodNames[methodIdx], signatures[methodIdx], false, false,
+                            checkAndScanMethod(loadedClassInfo, methodNames[methodIdx], signatures[methodIdx], false, false,
                                                false);
                         }
                     } else {
-                        markMethod(loadedClassInfos[j], rIdx);
-                        checkAndScanMethod(loadedClassInfos[j], rootMethods.methodNames[rIdx],
+                        markMethod(loadedClassInfo, rIdx);
+                        checkAndScanMethod(loadedClassInfo, rootMethods.methodNames[rIdx],
                                            rootMethods.methodSignatures[rIdx], false, false, false);
                     }
                 }
@@ -424,7 +407,7 @@ public class RecursiveMethodInstrumentor2 extends RecursiveMethodInstrumentor {
                 //if (!lookupInSuperIfNotFoundInThis && !checkSubclasses) System.out.println("Gonna scan potentially reachable " + className + "." + methodName + methodSignature);
                 scanBytecode(clazz, bytecode);
             } else if (constructorNotInstrumented) {
-                scanBytecode(clazz, bytecode);
+                scanMethod(clazz, idx);
             }
         }
 
