@@ -1,54 +1,32 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 /*
  * CPUTestCase.java
  *
  * Created on July 19, 2005, 5:20 PM
- *
- * To change this template, choose Tools | Options and locate the template under
- * the Source Creation and Management node. Right-click the template and choose
- * Open. You can then make changes to the template in the Source Editor.
  */
 package org.graalvm.visualvm.lib.jfluid.tests.jfluid.cpu;
 
@@ -174,14 +152,21 @@ public abstract class CPUTestCase extends CommonProfilerTestCase {
         return Math.abs(ideal - mctime) / 1000;
     }
 
+    protected double getPercentAtRow(FlatProfileContainer fpc, int row) {
+        double wholeNetTime = fpc.getWholeGraphNetTime0();
+        long tm = fpc.getTimeInMcs0AtRow(row);
+
+        return ((double)tm / wholeNetTime * 100);
+    }
+
     protected void checkCPUResults(FlatProfileContainer fpc, HashMap methods, String[] measuredMethodsFilter) {
         double percent = 0.0;
 
         for (int row = 0; row < fpc.getNRows(); row++) {
-            percent += fpc.getPercentAtRow(row);
+            percent += getPercentAtRow(fpc, row);
 
-            for (int mets = 0; mets < measuredMethodsFilter.length; mets++) {
-                if (fpc.getMethodNameAtRow(row).startsWith(measuredMethodsFilter[mets])) {
+            for (String measuredMethodsFilter1 : measuredMethodsFilter) {
+                if (fpc.getMethodNameAtRow(row).startsWith(measuredMethodsFilter1)) {
                     Measured m = (Measured) (methods.get(fpc.getMethodNameAtRow(row)));
 
                     if (m == null) {
@@ -197,7 +182,7 @@ public abstract class CPUTestCase extends CommonProfilerTestCase {
 
                         if ((tm > m.time) || (inv > m.invocations)) {
                             log("\n!!!Decreasing values: method " + fpc.getMethodNameAtRow(row) + " current time " + m.time
-                                + " invocations " + m.invocations + " but was time=" + tm + " invocations=" + inv + "\n");
+                                    + " invocations " + m.invocations + " but was time=" + tm + " invocations=" + inv + "\n");
                             assertFalse("Unacceptable results - decresing values (issue 65187)", true);
                         }
                     }
@@ -232,10 +217,9 @@ public abstract class CPUTestCase extends CommonProfilerTestCase {
             }
 
             if (refMethods != null) {
-                for (int mets = 0; mets < refMethods.length; mets++) {
+                for (String refMethod : refMethods) {
                     String mname = fpc.getMethodNameAtRow(row);
-
-                    if (mname.startsWith(refMethods[mets]) && !refMethodsList.contains(mname)) {
+                    if (mname.startsWith(refMethod) && !refMethodsList.contains(mname)) {
                         refMethodsList.add(mname);
                     }
                 }
@@ -308,8 +292,8 @@ public abstract class CPUTestCase extends CommonProfilerTestCase {
         String[] mets = snapshot.getInstrMethodNames();
         log("Instrumented methods:");
 
-        for (int i = 0; i < mets.length; i++) {
-            log(mets[i]);
+        for (String met : mets) {
+            log(met);
         }
     }
 
@@ -385,7 +369,7 @@ public abstract class CPUTestCase extends CommonProfilerTestCase {
 
             setStatus(STATUS_MEASURED);
 
-            if (methods.size() > 0) {
+            if (!methods.isEmpty()) {
                 Collections.sort(methods);
 
                 for (int mets = 0; mets < methods.size(); mets++) {
@@ -493,7 +477,7 @@ public abstract class CPUTestCase extends CommonProfilerTestCase {
                 time = System.currentTimeMillis();
             }
 
-            if (methods.size() == 0) {
+            if (methods.isEmpty()) {
                 assertTrue("Results were not on the server - issue 65185", false);
             }
         } catch (Exception ex) {
