@@ -1,57 +1,39 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2022, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.profiler.api;
 
-import org.graalvm.visualvm.lib.common.GlobalProfilingSettings;
-import org.openide.util.NbBundle;
-import org.openide.util.NbPreferences;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.prefs.Preferences;
+import org.graalvm.visualvm.lib.common.GlobalProfilingSettings;
 import org.graalvm.visualvm.lib.common.ProfilingSettings;
 import org.graalvm.visualvm.lib.jfluid.global.CommonConstants;
+import org.openide.util.NbBundle;
+import org.openide.util.NbPreferences;
 
 
 /**
@@ -418,8 +400,8 @@ public final class ProfilerIDESettings implements GlobalProfilingSettings {
      * @param value The value that should be used without displaying the notification or null to cleat the Do not show
      *              again (i.e. start displaying the notifications again.
      *
-     * @see org.graalvm.visualvm.lib.profiler.ui.ProfilerDialogs.DNSAConfirmation
-     * @see org.graalvm.visualvm.lib.profiler.ui.ProfilerDialogs.DNSAMessage
+     * @see org.graalvm.visualvm.lib.profiler.impl.ProfilerDialogs.DNSAConfirmation
+     * @see org.graalvm.visualvm.lib.profiler.impl.ProfilerDialogs.DNSAMessage
      */
     public void setDoNotShowAgain(final String key, final String value) {
         if (value != null) {
@@ -440,8 +422,8 @@ public final class ProfilerIDESettings implements GlobalProfilingSettings {
      * @return The value that should be used without displaying the notification or null if the notification should
      *         be displayed
      *
-     * @see org.graalvm.visualvm.lib.profiler.ui.ProfilerDialogs.DNSAConfirmation
-     * @see org.graalvm.visualvm.lib.profiler.ui.ProfilerDialogs.DNSAMessage
+     * @see org.graalvm.visualvm.lib.profiler.impl.ProfilerDialogs.DNSAConfirmation
+     * @see org.graalvm.visualvm.lib.profiler.impl.ProfilerDialogs.DNSAMessage
      */
     public String getDoNotShowAgain(final String key) {
         return getDNSAMap().get(key);
@@ -576,8 +558,8 @@ public final class ProfilerIDESettings implements GlobalProfilingSettings {
      *
      * Clears the Do not show again, so that all confirmations are displayed again.
      *
-     * @see org.graalvm.visualvm.lib.profiler.ui.ProfilerDialogs.DNSAConfirmation
-     * @see org.graalvm.visualvm.lib.profiler.ui.ProfilerDialogs.DNSAMessage
+     * @see org.graalvm.visualvm.lib.profiler.impl.ProfilerDialogs.DNSAConfirmation
+     * @see org.graalvm.visualvm.lib.profiler.impl.ProfilerDialogs.DNSAMessage
      */
     public void clearDoNotShowAgainMap() {
         getDNSAMap().clear();
@@ -603,9 +585,8 @@ public final class ProfilerIDESettings implements GlobalProfilingSettings {
 
         if (allPairs != null) {
             String[] pairs = allPairs.split(":"); //NOI18N
-
-            for (int i = 0; i < pairs.length; i++) {
-                String[] elems = pairs[i].split(","); //NOI18N
+            for (String pair : pairs) {
+                String[] elems = pair.split(","); //NOI18N
                 assert elems.length == 2;
                 dnsaMap.put(elems[0], elems[1]);
             }
@@ -633,10 +614,10 @@ public final class ProfilerIDESettings implements GlobalProfilingSettings {
 
         String toStore = sb.toString();
 
-        if (toStore.length() > 0) {
-            getPreferences().put(DNSA_SETTINGS_KEY, toStore);
-        } else {
+        if (toStore.isEmpty()) {
             getPreferences().remove(DNSA_SETTINGS_KEY);
+        } else {
+            getPreferences().put(DNSA_SETTINGS_KEY, toStore);
         }
     }
 }
