@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,17 +25,6 @@
 
 package org.graalvm.visualvm.profiler;
 
-import org.graalvm.visualvm.application.Application;
-import org.graalvm.visualvm.core.datasupport.DataRemovedListener;
-import org.graalvm.visualvm.core.datasupport.Stateful;
-import org.graalvm.visualvm.core.ui.DataSourceView;
-import org.graalvm.visualvm.core.ui.DesktopUtils;
-import org.graalvm.visualvm.core.ui.components.DataViewComponent;
-import org.graalvm.visualvm.profiling.presets.PresetSelector;
-import org.graalvm.visualvm.profiling.presets.ProfilerPreset;
-import org.graalvm.visualvm.profiling.presets.ProfilerPresets;
-import org.graalvm.visualvm.uisupport.HTMLLabel;
-import org.graalvm.visualvm.uisupport.HTMLTextArea;
 import java.awt.BorderLayout;
 import java.awt.Dimension;
 import java.awt.Font;
@@ -48,7 +37,6 @@ import java.awt.event.MouseEvent;
 import java.beans.PropertyChangeEvent;
 import java.beans.PropertyChangeListener;
 import java.net.URL;
-import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.List;
 import javax.swing.BorderFactory;
@@ -60,16 +48,27 @@ import javax.swing.JPanel;
 import javax.swing.JToggleButton;
 import javax.swing.SwingUtilities;
 import javax.swing.Timer;
+import org.graalvm.visualvm.application.Application;
 import org.graalvm.visualvm.core.VisualVM;
-import org.graalvm.visualvm.lib.jfluid.TargetAppRunner;
+import org.graalvm.visualvm.core.datasupport.DataRemovedListener;
+import org.graalvm.visualvm.core.datasupport.Stateful;
+import org.graalvm.visualvm.core.ui.DataSourceView;
+import org.graalvm.visualvm.core.ui.DesktopUtils;
+import org.graalvm.visualvm.core.ui.components.DataViewComponent;
 import org.graalvm.visualvm.lib.common.AttachSettings;
 import org.graalvm.visualvm.lib.common.ProfilingSettings;
 import org.graalvm.visualvm.lib.common.event.ProfilingStateEvent;
 import org.graalvm.visualvm.lib.common.event.ProfilingStateListener;
+import org.graalvm.visualvm.lib.jfluid.TargetAppRunner;
 import org.graalvm.visualvm.lib.profiler.NetBeansProfiler;
 import org.graalvm.visualvm.lib.profiler.api.ProfilerDialogs;
 import org.graalvm.visualvm.lib.profiler.api.ProfilerIDESettings;
 import org.graalvm.visualvm.lib.profiler.utilities.ProfilerUtils;
+import org.graalvm.visualvm.profiling.presets.PresetSelector;
+import org.graalvm.visualvm.profiling.presets.ProfilerPreset;
+import org.graalvm.visualvm.profiling.presets.ProfilerPresets;
+import org.graalvm.visualvm.uisupport.HTMLLabel;
+import org.graalvm.visualvm.uisupport.HTMLTextArea;
 import org.openide.util.ImageUtilities;
 import org.openide.util.NbBundle;
 import org.openide.util.WeakListeners;
@@ -88,21 +87,23 @@ final class ApplicationProfilerView extends DataSourceView {
     private CPUSettingsSupport cpuSettings;
     private MemorySettingsSupport memorySettings;
     private JDBCSettingsSupport jdbcSettings;
+    private LocksSettingsSupport locksSettings;
     
-    private DefaultComboBoxModel selectorModel;
+    private DefaultComboBoxModel<ProfilerPreset> selectorModel;
     private List<PresetSelector> allSelectors;
     
     private boolean classSharingBreaksProfiling;
 
     
-    public ApplicationProfilerView(final Application application) {
+    ApplicationProfilerView(final Application application) {
         super(application, NbBundle.getMessage(ApplicationProfilerView.class, "LBL_Profiler"), // NOI18N
               new ImageIcon(ImageUtilities.loadImage(IMAGE_PATH, true)).getImage(), 40, false);   
         cpuSettings = new CPUSettingsSupport() {
             public boolean presetValid() {
                 return cpuSettings.settingsValid() &&
                        memorySettings.settingsValid() &&
-                       jdbcSettings.settingsValid();
+                       jdbcSettings.settingsValid() &&
+                       locksSettings.settingsValid();
             }
             public PresetSelector createSelector(Runnable presetSynchronizer) {
                 return ApplicationProfilerView.this.createSelector(presetSynchronizer, application);
@@ -112,7 +113,8 @@ final class ApplicationProfilerView extends DataSourceView {
             public boolean presetValid() {
                 return cpuSettings.settingsValid() &&
                        memorySettings.settingsValid() &&
-                       jdbcSettings.settingsValid();
+                       jdbcSettings.settingsValid() &&
+                       locksSettings.settingsValid();
             }
             public PresetSelector createSelector(Runnable presetSynchronizer) {
                 return ApplicationProfilerView.this.createSelector(presetSynchronizer, application);
@@ -122,7 +124,19 @@ final class ApplicationProfilerView extends DataSourceView {
             public boolean presetValid() {
                 return cpuSettings.settingsValid() &&
                        memorySettings.settingsValid() &&
-                       jdbcSettings.settingsValid();
+                       jdbcSettings.settingsValid() &&
+                       locksSettings.settingsValid();
+            }
+            public PresetSelector createSelector(Runnable presetSynchronizer) {
+                return ApplicationProfilerView.this.createSelector(presetSynchronizer, application);
+            }
+        };
+        locksSettings = new LocksSettingsSupport() {
+            public boolean presetValid() {
+                return cpuSettings.settingsValid() &&
+                       memorySettings.settingsValid() &&
+                       jdbcSettings.settingsValid() &&
+                       locksSettings.settingsValid();
             }
             public PresetSelector createSelector(Runnable presetSynchronizer) {
                 return ApplicationProfilerView.this.createSelector(presetSynchronizer, application);
@@ -153,6 +167,7 @@ final class ApplicationProfilerView extends DataSourceView {
             cpuSettings.updateSettings(preset);
             memorySettings.updateSettings(preset);
             jdbcSettings.updateSettings(preset);
+            locksSettings.updateSettings(preset);
             
             if (ProfilingSettings.isCPUSettings(settings)) {
                 masterViewSupport.showCPUSettings();
@@ -168,8 +183,8 @@ final class ApplicationProfilerView extends DataSourceView {
     }
     
     private PresetSelector createSelector(Runnable presetSynchronizer, Application application) {
-        if (selectorModel == null) selectorModel = new DefaultComboBoxModel();
-        if (allSelectors == null) allSelectors = new ArrayList();
+        if (selectorModel == null) selectorModel = new DefaultComboBoxModel<>();
+        if (allSelectors == null) allSelectors = new ArrayList<>();
         PresetSelector selector = ProfilerPresets.getInstance().createSelector(
                                   application, selectorModel, allSelectors, presetSynchronizer);
         allSelectors.add(selector);
@@ -183,7 +198,7 @@ final class ApplicationProfilerView extends DataSourceView {
         Application application = (Application)getDataSource();
         ProfilingResultsSupport profilingResultsSupport = new ProfilingResultsSupport();
         
-        masterViewSupport = new MasterViewSupport(application, profilingResultsSupport, cpuSettings, memorySettings, jdbcSettings, classSharingBreaksProfiling) {
+        masterViewSupport = new MasterViewSupport(application, profilingResultsSupport, cpuSettings, memorySettings, jdbcSettings, locksSettings, classSharingBreaksProfiling) {
             void showCPUSettings() {
                 if (dvc != null) {
                     cpuSettings.showSettings(dvc);
@@ -212,6 +227,7 @@ final class ApplicationProfilerView extends DataSourceView {
         dvc.addDetailsView(cpuSettings.getDetailsView(), DataViewComponent.TOP_RIGHT);
         dvc.addDetailsView(memorySettings.getDetailsView(), DataViewComponent.TOP_RIGHT);
         dvc.addDetailsView(jdbcSettings.getDetailsView(), DataViewComponent.TOP_RIGHT);
+//        dvc.addDetailsView(locksSettings.getDetailsView(), DataViewComponent.TOP_RIGHT);
 //        dvc.hideDetailsArea(DataViewComponent.TOP_RIGHT);
 
         if (cachedPreset != null) selectPreset(cachedPreset, cachedSettings);
@@ -220,7 +236,7 @@ final class ApplicationProfilerView extends DataSourceView {
     }
     
     protected void willBeAdded() {
-        classSharingBreaksProfiling = ProfilerSupport.getInstance().classSharingBreaksProfiling((Application)getDataSource());
+        classSharingBreaksProfiling = ProfilerSupport.classSharingBreaksProfiling((Application)getDataSource());
     }
     
     protected void removed() {
@@ -237,6 +253,7 @@ final class ApplicationProfilerView extends DataSourceView {
         private CPUSettingsSupport cpuSettingsSupport;
         private MemorySettingsSupport memorySettingsSupport;
         private JDBCSettingsSupport jdbcSettingsSupport;
+        private LocksSettingsSupport locksSettingsSupport;
         private AttachSettings attachSettings;
         private Timer timer;
         private int lastInstrValue = -1;
@@ -248,18 +265,22 @@ final class ApplicationProfilerView extends DataSourceView {
         
         private boolean classSharingBreaksProfiling;
         
+        private final NetBeansProfiler profiler;
         
         private ProfilingResultsSupport.ResultsView results;
     
         
-        public MasterViewSupport(final Application application, ProfilingResultsSupport profilingResultsView,
+        MasterViewSupport(final Application application, ProfilingResultsSupport profilingResultsView,
                 CPUSettingsSupport cpuSettingsSupport, MemorySettingsSupport memorySettingsSupport,
-                JDBCSettingsSupport jdbcSettingsSupport, boolean classSharingBreaksProfiling) {
+                JDBCSettingsSupport jdbcSettingsSupport, LocksSettingsSupport locksSettingsSupport,
+                boolean classSharingBreaksProfiling) {
+            profiler = NetBeansProfiler.getDefaultNB();
             this.application = application;
             this.profilingResultsView = profilingResultsView;
             this.cpuSettingsSupport = cpuSettingsSupport;
             this.memorySettingsSupport = memorySettingsSupport;
             this.jdbcSettingsSupport = jdbcSettingsSupport;
+            this.locksSettingsSupport = locksSettingsSupport;
             this.classSharingBreaksProfiling = classSharingBreaksProfiling;
             
             initComponents();
@@ -268,7 +289,6 @@ final class ApplicationProfilerView extends DataSourceView {
             
             timer = new Timer(1000, this);
             timer.setInitialDelay(1000);
-            NetBeansProfiler.getDefaultNB().addProfilingStateListener(this);
             
             // TODO: should listen for PROPERTY_AVAILABLE instead of DataSource removal
             application.notifyWhenRemoved(this);
@@ -291,7 +311,7 @@ final class ApplicationProfilerView extends DataSourceView {
             applicationTerminated = true;
             timer.stop();
             timer.removeActionListener(MasterViewSupport.this);
-            NetBeansProfiler.getDefaultNB().removeProfilingStateListener(MasterViewSupport.this);
+            profiler.removeProfilingStateListener(MasterViewSupport.this);
             ProfilerSupport.getInstance().setProfiledApplication(null);
             lastInstrValue = -1;
             SwingUtilities.invokeLater(new Runnable() {
@@ -311,7 +331,7 @@ final class ApplicationProfilerView extends DataSourceView {
         public void viewRemoved() {
             timer.stop();
             timer.removeActionListener(MasterViewSupport.this);
-            NetBeansProfiler.getDefaultNB().removeProfilingStateListener(MasterViewSupport.this);
+            profiler.removeProfilingStateListener(MasterViewSupport.this);
         }
         
         public void actionPerformed(ActionEvent e) {
@@ -324,6 +344,7 @@ final class ApplicationProfilerView extends DataSourceView {
             if (cpuButton.isSelected()) return new CPULivePanel(application);
             if (memoryButton.isSelected()) return new MemoryLivePanel(application);
             if (jdbcButton.isSelected()) return new JDBCLivePanel(application);
+            if (locksButton.isSelected()) return new LocksLivePanel(application);
             return null;
         }
         
@@ -334,6 +355,7 @@ final class ApplicationProfilerView extends DataSourceView {
             internalChange = true;
             memoryButton.setSelected(false);
             jdbcButton.setSelected(false);
+            locksButton.setSelected(false);
             internalChange = false;
             if (!cpuSettingsSupport.settingsValid()) {
                 internalChange = true;
@@ -344,9 +366,9 @@ final class ApplicationProfilerView extends DataSourceView {
                 ProfilerDialogs.displayError(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_Incorrect_CPU_settings")); // NOI18N
             } else {
                 cpuSettingsSupport.saveSettings();
-                if (NetBeansProfiler.getDefaultNB().getProfilingState() == NetBeansProfiler.PROFILING_RUNNING) {
+                if (profiler.getProfilingState() == NetBeansProfiler.PROFILING_RUNNING) {
                   ProfilerUtils.runInProfilerRequestProcessor(new Runnable() {
-                    public void run() { NetBeansProfiler.getDefaultNB().modifyCurrentProfiling(cpuSettingsSupport.getSettings()); }
+                    public void run() { profiler.modifyCurrentProfiling(cpuSettingsSupport.getSettings()); }
                   });
                 } else {
                   disableControlButtons();
@@ -366,6 +388,7 @@ final class ApplicationProfilerView extends DataSourceView {
             internalChange = true;
             cpuButton.setSelected(false);
             jdbcButton.setSelected(false);
+            locksButton.setSelected(false);
             internalChange = false;
             if (!memorySettingsSupport.settingsValid()) {
                 internalChange = true;
@@ -376,10 +399,10 @@ final class ApplicationProfilerView extends DataSourceView {
                 ProfilerDialogs.displayError(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_Incorrect_Memory_settings")); // NOI18N
             } else {
               memorySettingsSupport.saveSettings();
-              if (NetBeansProfiler.getDefaultNB().getProfilingState() == NetBeansProfiler.PROFILING_RUNNING) {
+              if (  profiler.getProfilingState() == NetBeansProfiler.PROFILING_RUNNING) {
                 ProfilerUtils.runInProfilerRequestProcessor(new Runnable() {
                   public void run() {
-                    NetBeansProfiler.getDefaultNB().modifyCurrentProfiling(memorySettingsSupport.getSettings()); 
+                                profiler.modifyCurrentProfiling(memorySettingsSupport.getSettings()); 
                   }
                 });
               } else {
@@ -402,10 +425,10 @@ final class ApplicationProfilerView extends DataSourceView {
             memoryButton.setSelected(false);
             internalChange = false;
             jdbcSettingsSupport.saveSettings();
-            if (NetBeansProfiler.getDefaultNB().getProfilingState() == NetBeansProfiler.PROFILING_RUNNING) {
+            if (profiler.getProfilingState() == NetBeansProfiler.PROFILING_RUNNING) {
               ProfilerUtils.runInProfilerRequestProcessor(new Runnable() {
                 public void run() {
-                    NetBeansProfiler.getDefaultNB().modifyCurrentProfiling(jdbcSettingsSupport.getSettings()); 
+                    profiler.modifyCurrentProfiling(jdbcSettingsSupport.getSettings()); 
                 }
               });
             } else {
@@ -417,11 +440,37 @@ final class ApplicationProfilerView extends DataSourceView {
             }
           }
         }
+
+        private void handleLocksProfiling() {
+          if (internalChange) return;
+
+          if (locksButton.isSelected())  {
+            internalChange = true;
+            cpuButton.setSelected(false);
+            memoryButton.setSelected(false);
+            jdbcButton.setSelected(false);
+            internalChange = false;
+            locksSettingsSupport.saveSettings();
+            if (profiler.getProfilingState() == NetBeansProfiler.PROFILING_RUNNING) {
+              ProfilerUtils.runInProfilerRequestProcessor(new Runnable() {
+                public void run() {
+                    profiler.modifyCurrentProfiling(locksSettingsSupport.getSettings());
+                }
+              });
+            } else {
+              disableControlButtons();
+              ProfilerSupport.getInstance().setProfiledApplication(application);
+              ProfilerUtils.runInProfilerRequestProcessor(new Runnable() {
+                public void run() { startProfiling(application, locksSettingsSupport.getSettings()); }
+              });
+            }
+          }
+        }
         
         private void startProfiling(Application application, ProfilingSettings pSettings) {
           Runnable calibrationStartUpdater = new Runnable() {
               public void run() {
-                  ProfilerDialogs.displayInfo(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_calibration")); // NOI18N
+                  ProfilerDialogs.displayInfo(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_calibration", VisualVM.getInstance().getOptionsHandle())); // NOI18N
                   SwingUtilities.invokeLater(new Runnable() {
                       public void run() {
                           statusValueLabel.setText(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_calibration_progress")); // NOI18N
@@ -430,7 +479,8 @@ final class ApplicationProfilerView extends DataSourceView {
               }
           };
           if (CalibrationSupport.checkCalibration(application, calibrationStartUpdater, null)) {
-              NetBeansProfiler.getDefaultNB().attachToApp(pSettings, attachSettings);
+                profiler.addProfilingStateListener(this);
+                profiler.attachToApp(pSettings, attachSettings);
           } else {
               SwingUtilities.invokeLater(new Runnable() {
                 public void run() {
@@ -449,7 +499,7 @@ final class ApplicationProfilerView extends DataSourceView {
           disableControlButtons();
           ProfilerUtils.runInProfilerRequestProcessor(new Runnable() {
             public void run() {
-              NetBeansProfiler.getDefaultNB().detachFromApp();
+                profiler.detachFromApp();
             }
           });
         }
@@ -464,7 +514,7 @@ final class ApplicationProfilerView extends DataSourceView {
 
         private synchronized void refreshStatus() {
 
-          final int newState = NetBeansProfiler.getDefaultNB().getProfilingState();
+          final int newState = profiler.getProfilingState();
           final Application profiledApplication = ProfilerSupport.getInstance().getProfiledApplication();
           if (state != newState) {
             state = newState;
@@ -534,6 +584,7 @@ final class ApplicationProfilerView extends DataSourceView {
                   case NetBeansProfiler.PROFILING_STOPPED:
                     timer.stop();
                     statusValueLabel.setText(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_profiling_stopped")); // NOI18N
+                    profiler.removeProfilingStateListener(MasterViewSupport.this);
                     break;
                 }
               }
@@ -542,13 +593,12 @@ final class ApplicationProfilerView extends DataSourceView {
         }
 
         private void updateRunningText() {
-            ProfilingSettings currentSettings = NetBeansProfiler.getDefaultNB().getLastProfilingSettings();
+            ProfilingSettings currentSettings = profiler.getLastProfilingSettings();
             int currentProfilingType = currentSettings != null ? currentSettings.getProfilingType() : Integer.MIN_VALUE;
             if (cpuSettingsSupport.getSettings().getProfilingType() == currentProfilingType) {
                 int instrValue = TargetAppRunner.getDefault().getProfilingSessionStatus().getNInstrMethods();
                 if (lastInstrValue != instrValue)
-                    statusValueLabel.setText(MessageFormat.format(NbBundle.getMessage(ApplicationProfilerView.class,
-                            "MSG_profiling_running_methods"), new Object[] { instrValue })); // NOI18N
+                    statusValueLabel.setText(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_profiling_running_methods", instrValue)); // NOI18N
                 lastInstrValue = instrValue;
             } else if (memorySettingsSupport.getSettings().getProfilingType() == currentProfilingType) {
                 int instrValue = TargetAppRunner.getDefault().getProfilingSessionStatus().getNInstrClasses();
@@ -556,20 +606,16 @@ final class ApplicationProfilerView extends DataSourceView {
                     int allocEvery = currentSettings.getAllocTrackEvery();
                     switch (allocEvery) {
                         case 1:
-                            statusValueLabel.setText(MessageFormat.format(NbBundle.getMessage(ApplicationProfilerView.class,
-                            "MSG_profiling_running_classes_1"), new Object[] { instrValue, allocEvery })); // NOI18N
+                            statusValueLabel.setText(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_profiling_running_classes_1", instrValue, allocEvery)); // NOI18N
                             break;
                         case 2:
-                            statusValueLabel.setText(MessageFormat.format(NbBundle.getMessage(ApplicationProfilerView.class,
-                            "MSG_profiling_running_classes_2"), new Object[] { instrValue, allocEvery })); // NOI18N
+                            statusValueLabel.setText(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_profiling_running_classes_2", instrValue, allocEvery)); // NOI18N
                             break;
                         case 3:
-                            statusValueLabel.setText(MessageFormat.format(NbBundle.getMessage(ApplicationProfilerView.class,
-                            "MSG_profiling_running_classes_3"), new Object[] { instrValue, allocEvery })); // NOI18N
+                            statusValueLabel.setText(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_profiling_running_classes_3", instrValue, allocEvery)); // NOI18N
                             break;
                         default:
-                            statusValueLabel.setText(MessageFormat.format(NbBundle.getMessage(ApplicationProfilerView.class,
-                            "MSG_profiling_running_classes_N"), new Object[] { instrValue, allocEvery })); // NOI18N
+                            statusValueLabel.setText(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_profiling_running_classes_N", instrValue, allocEvery)); // NOI18N
                     }
                 }
                     
@@ -577,8 +623,7 @@ final class ApplicationProfilerView extends DataSourceView {
             } else if (jdbcSettingsSupport.getSettings().getProfilingType() == currentProfilingType) {
                 int instrValue = TargetAppRunner.getDefault().getProfilingSessionStatus().getNInstrMethods();
                 if (lastInstrValue != instrValue)
-                    statusValueLabel.setText(MessageFormat.format(NbBundle.getMessage(ApplicationProfilerView.class,
-                            "MSG_profiling_running_methods"), new Object[] { instrValue })); // NOI18N
+                    statusValueLabel.setText(NbBundle.getMessage(ApplicationProfilerView.class, "MSG_profiling_running_methods", instrValue)); // NOI18N
                 lastInstrValue = instrValue;
             }
         }
@@ -600,29 +645,40 @@ final class ApplicationProfilerView extends DataSourceView {
           cpuButton.setSelected(false);
           memoryButton.setSelected(false);
           jdbcButton.setSelected(false);
+          locksButton.setSelected(false);
           internalChange = false;
         }
         
         private void updateControlButtons() {
-            ProfilingSettings currentSettings = NetBeansProfiler.getDefaultNB().getLastProfilingSettings();
+            ProfilingSettings currentSettings = profiler.getLastProfilingSettings();
             int currentProfilingType = currentSettings != null ? currentSettings.getProfilingType() : Integer.MIN_VALUE;
             if (cpuSettingsSupport.getSettings().getProfilingType() == currentProfilingType && !cpuButton.isSelected()) {
                 internalChange = true;
                 cpuButton.setSelected(true);
                 memoryButton.setSelected(false);
                 jdbcButton.setSelected(false);
+                locksButton.setSelected(false);
                 internalChange = false;
             } else if (memorySettingsSupport.getSettings().getProfilingType() == currentProfilingType && !memoryButton.isSelected()) {
                 internalChange = true;
                 cpuButton.setSelected(false);
                 memoryButton.setSelected(true);
                 jdbcButton.setSelected(false);
+                locksButton.setSelected(false);
                 internalChange = false;
             } else if (jdbcSettingsSupport.getSettings().getProfilingType() == currentProfilingType && !jdbcButton.isSelected()) {
                 internalChange = true;
                 cpuButton.setSelected(false);
                 memoryButton.setSelected(false);
                 jdbcButton.setSelected(true);
+                locksButton.setSelected(false);
+                internalChange = false;
+            } else if (locksSettingsSupport.getSettings().getProfilingType() == currentProfilingType && !jdbcButton.isSelected()) {
+                internalChange = true;
+                cpuButton.setSelected(false);
+                memoryButton.setSelected(false);
+                jdbcButton.setSelected(false);
+                locksButton.setSelected(true);
                 internalChange = false;
             }
         }
@@ -632,13 +688,15 @@ final class ApplicationProfilerView extends DataSourceView {
           cpuButton.setEnabled(enabled);
           memoryButton.setEnabled(enabled);
           jdbcButton.setEnabled(enabled);
-          stopButton.setEnabled(NetBeansProfiler.getDefaultNB().getTargetAppRunner().targetAppIsRunning());
+          locksButton.setEnabled(enabled);
+          stopButton.setEnabled(profiler.getTargetAppRunner().targetAppIsRunning());
         }
 
         private void disableControlButtons() {
           cpuButton.setEnabled(false);
           memoryButton.setEnabled(false);
           jdbcButton.setEnabled(false);
+          locksButton.setEnabled(false);
           stopButton.setEnabled(false);
         }
 
@@ -758,6 +816,21 @@ final class ApplicationProfilerView extends DataSourceView {
               constraints.insets = new Insets(4, 8, 0, 0);
               controlPanel.add(jdbcButton, constraints);
 
+              // locksButton
+              locksButton = new OneWayToggleButton(NbBundle.getMessage(ApplicationProfilerView.class, "LBL_Locks"));  // NOI18N
+              locksButton.setIcon(new ImageIcon(ImageUtilities.loadImage("org/graalvm/visualvm/profiler/resources/locks.png", true)));   // NOI18N
+              locksButton.addActionListener(new ActionListener() {
+                public void actionPerformed(ActionEvent e) { handleLocksProfiling(); }
+              });
+              constraints = new GridBagConstraints();
+              constraints.gridx = 5;
+              constraints.gridy = 2;
+              constraints.gridwidth = 1;
+              constraints.fill = GridBagConstraints.NONE;
+              constraints.anchor = GridBagConstraints.WEST;
+              constraints.insets = new Insets(4, 8, 0, 0);
+              controlPanel.add(locksButton, constraints);
+
               // stopButton
               stopButton = new JButton(NbBundle.getMessage(ApplicationProfilerView.class, "LBL_Stop")); // NOI18N
               stopButton.setIcon(new ImageIcon(ImageUtilities.loadImage("org/graalvm/visualvm/profiler/resources/stop.png", true)));   // NOI18N
@@ -767,7 +840,7 @@ final class ApplicationProfilerView extends DataSourceView {
               stopButton.setEnabled(false);
               stopButton.setDefaultCapable(false); // Button size
               constraints = new GridBagConstraints();
-              constraints.gridx = 5;
+              constraints.gridx = 6;
               constraints.gridy = 2;
               constraints.gridwidth = 1;
               constraints.fill = GridBagConstraints.NONE;
@@ -843,10 +916,12 @@ final class ApplicationProfilerView extends DataSourceView {
               Dimension cpuD     = cpuButton.getPreferredSize();
               Dimension memoryD  = memoryButton.getPreferredSize();
               Dimension jdbcD    = jdbcButton.getPreferredSize();
+              Dimension locksD   = locksButton.getPreferredSize();
               Dimension stopD    = stopButton.getPreferredSize();
 
               Dimension maxD = new Dimension(Math.max(cpuD.width, memoryD.width), Math.max(cpuD.height, memoryD.height));
               maxD = new Dimension(Math.max(maxD.width, jdbcD.width), Math.max(maxD.height, jdbcD.height));
+              maxD = new Dimension(Math.max(maxD.width, locksD.width), Math.max(maxD.height, locksD.height));
               maxD = new Dimension(Math.max(maxD.width, stopD.width), Math.max(maxD.height, stopD.height));
 
               cpuButton.setPreferredSize(maxD);
@@ -855,6 +930,8 @@ final class ApplicationProfilerView extends DataSourceView {
               memoryButton.setMinimumSize(maxD);
               jdbcButton.setPreferredSize(maxD);
               jdbcButton.setMinimumSize(maxD);
+              locksButton.setPreferredSize(maxD);
+              locksButton.setMinimumSize(maxD);
               stopButton.setPreferredSize(maxD);
               stopButton.setMinimumSize(maxD);
             
@@ -870,6 +947,7 @@ final class ApplicationProfilerView extends DataSourceView {
         private JToggleButton cpuButton;
         private JToggleButton memoryButton;
         private JToggleButton jdbcButton;
+        private JToggleButton locksButton;
         private JButton stopButton;
         private JLabel statusLabel;
         private HTMLLabel statusValueLabel;
@@ -879,7 +957,7 @@ final class ApplicationProfilerView extends DataSourceView {
     
     private static final class OneWayToggleButton extends JToggleButton {
     
-        public OneWayToggleButton(String text) {
+        OneWayToggleButton(String text) {
           super(text);
         }
 
