@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -43,7 +43,7 @@ import java.io.IOException;
 import java.io.StringWriter;
 import java.io.Writer;
 import java.net.URL;
-import java.util.Hashtable;
+import java.util.HashMap;
 import java.util.Map;
 import java.util.ResourceBundle;
 import javax.swing.*;
@@ -75,7 +75,7 @@ public class HTMLTextArea extends JEditorPane implements HyperlinkListener, Mous
     private static class ExtendedHTMLWriter extends HTMLWriter {
         //~ Constructors ---------------------------------------------------------------------------------------------------------
 
-        public ExtendedHTMLWriter(Writer w, HTMLDocument doc, int pos, int len) {
+        ExtendedHTMLWriter(Writer w, HTMLDocument doc, int pos, int len) {
             super(w, doc, pos, len);
             setLineLength(Integer.MAX_VALUE);
         }
@@ -154,7 +154,7 @@ public class HTMLTextArea extends JEditorPane implements HyperlinkListener, Mous
     private static class NcrToUnicode {
         //~ Static fields/initializers -------------------------------------------------------------------------------------------
 
-        private static Map entities;
+        private static Map<String,String> entities;
 
         //~ Methods --------------------------------------------------------------------------------------------------------------
 
@@ -186,7 +186,7 @@ public class HTMLTextArea extends JEditorPane implements HyperlinkListener, Mous
                 if (tok.charAt(0) == '#') { //NOI18N
 
                     if (tok.equals("#160")) { //NOI18N
-                        ostr.append((String) getEntities().get("nbsp")); //NOI18N // Fixes Issue 92818, "&nbsp;" is resolved as "&#160;" before decoding, so redirecting back to "&nbsp;"
+                        ostr.append(getEntities().get("nbsp")); //NOI18N // Fixes Issue 92818, "&nbsp;" is resolved as "&#160;" before decoding, so redirecting back to "&nbsp;"
                     } else {
                         tok = tok.substring(1);
 
@@ -204,7 +204,7 @@ public class HTMLTextArea extends JEditorPane implements HyperlinkListener, Mous
                         }
                     }
                 } else {
-                    tok = (String) getEntities().get(tok);
+                    tok = getEntities().get(tok);
 
                     if (tok != null) {
                         ostr.append(tok);
@@ -219,9 +219,9 @@ public class HTMLTextArea extends JEditorPane implements HyperlinkListener, Mous
             return ostr.toString();
         }
 
-        private static synchronized Map getEntities() {
+        private static synchronized Map<String,String> getEntities() {
             if (entities == null) {
-                entities = new Hashtable();
+                entities = new HashMap<>();
                 //Quotation mark
                 entities.put("quot", "\""); //NOI18N
                                             //Ampersand
@@ -741,8 +741,6 @@ public class HTMLTextArea extends JEditorPane implements HyperlinkListener, Mous
                                     .getTransferData(DataFlavor.stringFlavor).toString());
         } catch (Exception ex) {
         }
-
-        ;
     }
 
     protected JPopupMenu getPopupMenu() {
